@@ -24,7 +24,7 @@ from pkg_resources import parse_version
 
 import cachetools  # Force pyinstaller to import cache tools
 
-from PySide2.QtCore import (
+from PySide6.QtCore import (
     QCoreApplication,
     QSettings,
     QTranslator,
@@ -33,16 +33,21 @@ from PySide2.QtCore import (
     QLibraryInfo,
     Qt,
 )
-from PySide2.QtWidgets import QApplication, QSplashScreen
-from PySide2.QtGui import QPixmap
-from PySide2.QtNetwork import QNetworkProxy
+from PySide6.QtWidgets import QApplication, QSplashScreen, QStyleFactory, QColorDialog
+from PySide6.QtGui import QPixmap, QColor
+from PySide6.QtNetwork import QNetworkProxy
 
 # Custom imports
 from cutevariant.config import Config
 from cutevariant.gui import MainWindow, network, setFontPath, style
-import cutevariant.commons as cm
+import cutevariant.constants as cst
 from cutevariant import LOGGER
 from cutevariant import __version__
+import faulthandler
+import os
+
+
+faulthandler.enable()
 
 
 def main():
@@ -58,6 +63,7 @@ def main():
     QCoreApplication.setApplicationName("cutevariant")
     QCoreApplication.setApplicationVersion(__version__)
     QCoreApplication.setAttribute(Qt.AA_EnableHighDpiScaling, True)
+    QCoreApplication.setAttribute(Qt.AA_ShareOpenGLContexts, True)
     QCoreApplication.setAttribute(Qt.AA_UseHighDpiPixmaps, True)
 
     # Process command line arguments
@@ -69,16 +75,11 @@ def main():
     load_network_settings()
 
     # Load app styles
-    LOGGER.info("Load style")
     load_styles(app)
 
-    # # Uncomment those line to clear settings
-    # settings = QSettings()
-    # settings.clear()
-
     # Set icons set
     LOGGER.info("Load font")
-    setFontPath(cm.FONT_FILE)
+    setFontPath(cst.FONT_FILE)
 
     # Translations
     LOGGER.info("Load translation")
@@ -92,39 +93,31 @@ def main():
     LOGGER.info("Starting the GUI...")
     # Splash screen
     splash = QSplashScreen()
-    splash.setPixmap(QPixmap(cm.DIR_ICONS + "splash.png"))
+    splash.setPixmap(QPixmap(cst.DIR_ICONS + "splash.png"))
     splash.showMessage(f"Version {__version__}")
     splash.show()
     app.processEvents()
 
-    #  Drop settings if old version
+    # Check version
     settings = QSettings()
     settings_version = settings.value("version", None)
-    if settings_version is None or parse_version(settings_version) < parse_version(
-        __version__
-    ):
+    if settings_version is None or parse_version(settings_version) < parse_version(__version__):
         settings.clear()
         settings.setValue("version", __version__)
 
     # Display
     w = MainWindow()
 
-    # STYLES = cm.DIR_STYLES + "frameless.qss"
-    # with open(STYLES,"r") as file:
-    #     w.setStyleSheet(file.read())
-
     w.show()
     splash.finish(w)
-    app.exec_()
+    app.exec()
 
 
 def load_network_settings():
     config = Config("app")
     if "network" in config:
         _network = config.get("network", {})
-        proxy_type = network.PROXY_TYPES.get(
-            _network.get("type"), QNetworkProxy.NoProxy
-        )
+        proxy_type = network.PROXY_TYPES.get(_network.get("type"), QNetworkProxy.NoProxy)
         host_name = _network.get("host", "")
         port_number = _network.get("port", "")
         user_name = _network.get("username", "")
@@ -162,10 +155,14 @@ def load_styles(app):
     config = Config("app")
     # Display current style
     style_config = config.get("style", {})
-    theme = style_config.get("theme", cm.BASIC_STYLE)
-    # Apply selected style by calling on the method in style module based on its
-    # name; equivalent of style.dark(app)
-    getattr(style, theme.lower())(app)
+    theme = style_config.get("theme", cst.BASIC_STYLE)
+
+    mystyle = style.AppStyle()
+    mystyle.load_theme(theme.lower() + ".yaml")
+    app.setStyle(mystyle)
+
+    for index, (key, color) in enumerate(mystyle.colors().items()):
+        QColorDialog.setCustomColor(index, QColor(color))
 
 
 def load_translations(app):
@@ -178,7 +175,7 @@ def load_translations(app):
     app_settings = QSettings()
     locale_name = app_settings.value("ui/locale", "en")
 
-    # site-packages/PySide2/Qt/translations
+    # site-packages/PySide6/Qt/translations
     lib_info = QLibraryInfo.location(QLibraryInfo.TranslationsPath)
 
     # Qt translations
@@ -192,7 +189,7 @@ def load_translations(app):
 
     # App translations
     app_translator = QTranslator(app)
-    if app_translator.load(locale_name, directory=cm.DIR_TRANSLATIONS):
+    if app_translator.load(locale_name, directory=cst.DIR_TRANSLATIONS):
         app.installTranslator(app_translator)
     else:
         # Init setting
@@ -207,11 +204,19 @@ def process_arguments(app):
     # --version
     show_version = QCommandLineOption(
         ["version"],
-        QCoreApplication.translate(
-            "main", "Display the version of Cutevariant and exit."
-        ),
+        QCoreApplication.translate("main", "Display the version of Cutevariant and exit."),
     )
     parser.addOption(show_version)
+
+    # Config
+    config_option = QCommandLineOption(
+        ["c", "config"],
+        QCoreApplication.translate("config path", "Set the config path"),
+        "config",
+    )
+
+    parser.addOption(config_option)
+
     # -v, --verbose
     modify_verbosity = QCommandLineOption(
         ["v", "verbose"],
@@ -229,6 +234,14 @@ def process_arguments(app):
         print("Cutevariant " + __version__)
         exit()
 
+    if parser.isSet(config_option):
+        config_path = parser.value(config_option)
+        if os.path.isfile(config_path):
+            Config.USER_CONFIG_PATH = config_path
+
+        else:
+            LOGGER.error(f"{config_path} doesn't exists. Ignoring config")
+
     # if parser.isSet(modify_verbosity):
     # Set log level
     LOGGER.setLevel(parser.value(modify_verbosity).upper())
