@@ -7,7 +7,6 @@ from functools import partial
 # Custom imports
 import progressbar
 from columnar import columnar
-from cutevariant.core.importer import async_import_file
 from cutevariant.core import sql, vql, command
 from cutevariant.core.querybuilder import *
 from cutevariant import LOGGER
@@ -69,9 +68,7 @@ the arguments.""",
 
     # Common parser: Database file requirement #################################
     parent_parser = argparse.ArgumentParser(add_help=False)
-    parent_parser.add_argument(
-        "--db", help="SQLite database. By default, $CUTEVARIANT_DB is used."
-    )
+    parent_parser.add_argument("--db", help="SQLite database. By default, $CUTEVARIANT_DB is used.")
 
     # Create DB parser #########################################################
     createdb_parser = sub_parser.add_parser(
@@ -149,7 +146,6 @@ the arguments.""",
     # before the call of parse_args()
     if "html" in sys.argv:
         return parser
-
     args = parser.parse_args()
 
     if len(sys.argv) == 1:
@@ -174,10 +170,9 @@ the arguments.""",
         conn = sql.get_sql_connection(args.db)
         if conn:
             # TODO: bug ... max is not 100...
-            for i, message in progressbar.progressbar(
-                async_import_file(conn, args.input), redirect_stdout=True
-            ):
-                print(message)
+
+            with create_reader(args.input) as reader:
+                sql.import_reader(conn, reader)
 
         print("The database is successfully created!")
         exit()
@@ -201,9 +196,7 @@ the arguments.""",
             )
 
         if args.table == "samples":
-            display_sql_results(
-                (i.values() for i in sql.get_samples(conn)), ["id", "name"]
-            )
+            display_sql_results((i.values() for i in sql.get_samples(conn)), ["id", "name"])
 
         if args.table == "selections":
             display_sql_results(
@@ -212,9 +205,7 @@ the arguments.""",
             )
 
         if args.table == "wordsets":
-            display_sql_results(
-                (i.values() for i in sql.get_wordsets(conn)), ["id", "word_count"]
-            )
+            display_sql_results((i.values() for i in sql.get_wordsets(conn)), ["id", "word_count"])
 
     # Remove parser ############################################################
     if args.subparser == "remove":
