@@ -24,11 +24,12 @@ Fields contains columns to select according sql table that they belong to.
 import sqlite3
 import re
 from functools import lru_cache
-from ast import literal_eval
 
 # Custom imports
 from cutevariant.core import sql
 
+import cutevariant.constants as cst
+
 
 from cutevariant import LOGGER
 
@@ -38,19 +39,38 @@ from cutevariant import LOGGER
 # WORDSET["truc"]
 WORDSET_FUNC_NAME = "WORDSET"
 
-OPERATORS = {
+PY_TO_SQL_OPERATORS = {
     "$eq": "=",
     "$gt": ">",
     "$gte": ">=",
     "$lt": "<",
     "$lte": "<=",
     "$in": "IN",
-    "$ne": "!=",
     "$nin": "NOT IN",
+    "$ne": "!=",
     "$regex": "REGEXP",
+    "$nregex": "NOT REGEXP",
     "$and": "AND",
     "$or": "OR",
     "$has": "HAS",
+    "$nhas": "NOT HAS",
+}
+
+PY_TO_VQL_OPERATORS = {
+    "$eq": "=",
+    "$gt": ">",
+    "$gte": ">=",
+    "$lt": "<",
+    "$lte": "<=",
+    "$in": "IN",
+    "$nin": "!IN",
+    "$ne": "!=",
+    "$regex": "=~",
+    "$nregex": "!~",
+    "$and": "AND",
+    "$or": "OR",
+    "$has": "HAS",
+    "$nhas": "!HAS",
 }
 
 
@@ -87,7 +107,7 @@ def filters_to_flat(filters: dict):
     return flatten
 
 
-def is_annotation_join_required(fields, filters) -> bool:
+def is_annotation_join_required(fields, filters, order_by=None) -> bool:
     """Return True if SQL join annotation is required
 
     Args:
@@ -102,6 +122,12 @@ def is_annotation_join_required(fields, filters) -> bool:
         if field.startswith("ann."):
             return True
 
+    if order_by:
+        for by in order_by:
+            field, direction = by
+            if field.startswith("ann."):
+                return True
+
     for condition in filters_to_flat(filters):
 
         condition = list(condition.keys())[0]
@@ -111,7 +137,7 @@ def is_annotation_join_required(fields, filters) -> bool:
     return False
 
 
-def samples_join_required(fields, filters) -> list:
+def samples_join_required(fields, filters, order_by=None) -> list:
     """Return sample list of sql join is required
 
     Args:
@@ -129,6 +155,14 @@ def samples_join_required(fields, filters) -> list:
             sample = ".".join(sample)
             samples.add(sample)
 
+    if order_by:
+        for by in order_by:
+            field, direction = by
+            if field.startswith("samples"):
+                _, *sample, _ = field.split(".")
+                sample = ".".join(sample)
+                samples.add(sample)
+
     for condition in filters_to_flat(filters):
         key = list(condition.keys())[0]
         if key.startswith("samples"):
@@ -273,7 +307,8 @@ def condition_to_sql(item: dict, samples=None) -> str:
         condition_to_sql({"chr":3}) ==> `variants`.`chr `= 3
         condition_to_sql({"chr":{"$gte": 30}}) ==> `variants`.`chr `>= 3
         condition_to_sql({"ann.gene":{"$gte": 30}}) ==> `annotation`.`gene` >= 30
-        condition_to_sql({"samples.*.gt": 1 }) ==> (`samples.boby.gt = 1 AND samples.charles.gt = 1)
+        condition_to_sql({"samples.$all.gt": 1 }) ==> (`samples.boby.gt = 1 AND samples.charles.gt = 1)
+        condition_to_sql({"samples.$any.gt": 1 }) ==> (`samples.boby.gt = 1 OR samples.charles.gt = 1)
 
     """
 
@@ -303,24 +338,24 @@ def condition_to_sql(item: dict, samples=None) -> str:
         operator = "$eq"
         value = v
 
+    if isinstance(value, str):
+        value = value.replace("'", "''")
+
     # MAP operator
-    sql_operator = OPERATORS[operator]
+    sql_operator = PY_TO_SQL_OPERATORS[operator]
 
     # Optimisation REGEXP
     # use LIKE IF REGEXP HAS NO special caractere
-    if sql_operator == "REGEXP":
+    if "REGEXP" in sql_operator:
         special_caracter = "[]+.?*()^$"
         if not set(str(value)) & set(special_caracter):
-            sql_operator = "LIKE"
+            sql_operator = "LIKE" if sql_operator == "REGEXP" else "NOT LIKE"
             value = f"%{value}%"
 
-    if sql_operator == "HAS":
-
-        field = f"'&' || {field} || '&'"
-        sql_operator = "LIKE"
-        value = f"%&{value}&%"
-
-        # WHERE '&' || consequence || '&' LIKE "%&missense_variant&%"
+    if "HAS" in sql_operator:
+        field = f"'{cst.HAS_OPERATOR}' || {field} || '{cst.HAS_OPERATOR}'"
+        sql_operator = "LIKE" if sql_operator == "HAS" else "NOT LIKE"
+        value = f"%{cst.HAS_OPERATOR}{value}{cst.HAS_OPERATOR}%"
 
     # Cast value
     if isinstance(value, str):
@@ -347,22 +382,25 @@ def condition_to_sql(item: dict, samples=None) -> str:
 
     # Convert [1,2,3] =>  "(1,2,3)"
     if isinstance(value, list) or isinstance(value, tuple):
-        value = (
-            "("
-            + ",".join([f"'{i}'" if isinstance(i, str) else f"{i}" for i in value])
-            + ")"
-        )
+        value = "(" + ",".join([f"'{i}'" if isinstance(i, str) else f"{i}" for i in value]) + ")"
+
+    operator = None
+    condition = ""
 
     if table == "samples":
-        if name == "*" and samples:
+
+        if name == "$any":
+            operator = "OR"
+
+        if name == "$all":
+            operator = "AND"
+
+        if operator and samples:
 
             condition = (
                 "("
-                + " AND ".join(
-                    [
-                        f"`sample_{sample}`.`{k}` {sql_operator} {value}"
-                        for sample in samples
-                    ]
+                + f" {operator} ".join(
+                    [f"`sample_{sample}`.`{k}` {sql_operator} {value}" for sample in samples]
                 )
                 + ")"
             )
@@ -403,13 +441,17 @@ def condition_to_vql(item: dict) -> str:
         value = v
 
     # MAP operator
-    sql_operator = OPERATORS[operator]
-    # hack .. we want ~ instead of REGEXP
-    if sql_operator == "REGEXP":
-        sql_operator = "~"
+    sql_operator = PY_TO_VQL_OPERATORS[operator]
+    # # hack .. we want ~ instead of REGEXP
+    # if sql_operator == "REGEXP":
+    #     sql_operator = "=~"
+
+    # if sql_operator == "NOT REGEXP":
+    #     sql_operator = "!~"
 
     # Cast value
     if isinstance(value, str):
+        value = value.replace("'", "\\'")
         value = f"'{value}'"
 
     if isinstance(value, bool):
@@ -433,24 +475,73 @@ def condition_to_vql(item: dict) -> str:
 
     # Convert [1,2,3] =>  "(1,2,3)"
     if isinstance(value, list) or isinstance(value, tuple):
-        value = (
-            "("
-            + ",".join([f"'{i}'" if isinstance(i, str) else f"{i}" for i in value])
-            + ")"
-        )
+        value = "(" + ",".join([f"'{i}'" if isinstance(i, str) else f"{i}" for i in value]) + ")"
 
     if k.startswith("samples."):
         _, *name, k = k.split(".")
         name = ".".join(name)
-        k = f"samples['{name}'].{k}"
 
-        # k = f"sample{name}`.`{k}` {sql_operator} {value}"
+        if name == "$any":
+            name = "ANY"
+
+        elif name == "$all":
+            name = "ALL"
+
+        else:
+            name = f"'{name}'"
+
+        k = f"samples[{name}].{k}"
 
     condition = f"{k} {sql_operator} {value}"
 
     return condition
 
 
+def remove_field_in_filter(filters: dict, field: str = None) -> dict:
+    """Remove field from filter
+
+    Examples:
+
+        filters = {
+            "$and": [
+                {"chr": "chr1"},
+                {"pos": {"$gt": 111}},
+                {"$or":[
+                    {"chr": "chr7"},
+                    {"chr": "chr6"}
+                    ]
+                 }
+            ]}
+    Args:
+        filters (dict): A nested set of conditions
+        field (str): A field to remove from filter
+
+    Returns:
+        dict: New filters dict with field removed
+    """
+    # ---------------------------------
+    def recursive(obj):
+
+        output = {}
+        for k, v in obj.items():
+            if k in ["$and", "$or"]:
+                temp = []
+                for item in v:
+                    rec = recursive(item)
+                    if field not in item and rec:
+                        temp.append(rec)
+                if temp:
+                    output[k] = temp
+                    return output
+                # if not output[k]:
+                #     del output[k]
+            else:
+                output[k] = v
+                return output
+
+    return recursive(filters) or {}
+
+
 def filters_to_sql(filters: dict, samples=None) -> str:
     """Build a the SQL where clause from the nested set defined in filters
 
@@ -484,9 +575,7 @@ def filters_to_sql(filters: dict, samples=None) -> str:
         for k, v in obj.items():
             if k in ["$and", "$or"]:
                 conditions += (
-                    "("
-                    + f" {OPERATORS[k]} ".join([recursive(item) for item in v])
-                    + ")"
+                    "(" + f" {PY_TO_SQL_OPERATORS[k]} ".join([recursive(item) for item in v]) + ")"
                 )
 
             else:
@@ -535,9 +624,7 @@ def filters_to_vql(filters: dict) -> str:
         for k, v in obj.items():
             if k in ["$and", "$or"]:
                 conditions += (
-                    "("
-                    + f" {OPERATORS[k]} ".join([recursive(item) for item in v])
-                    + ")"
+                    "(" + f" {PY_TO_VQL_OPERATORS[k]} ".join([recursive(item) for item in v]) + ")"
                 )
 
             else:
@@ -585,12 +672,10 @@ def build_sql_query(
     fields,
     source="variants",
     filters={},
-    order_by=None,
-    order_desc=True,
+    order_by=[],
     limit=50,
     offset=0,
-    group_by={},
-    having={},  # {"op":">", "value": 3  }
+    selected_samples=[],
     **kwargs,
 ):
     """Build SQL SELECT query
@@ -599,9 +684,8 @@ def build_sql_query(
         fields (list): List of fields
         source (str): source of the virtual table ( see: selection )
         filters (dict): nested condition tree
-        order_by (str/None): Order by field;
+        order_by (list[(str,bool)]): list of tuple (fieldname, is_ascending) ;
             If None, order_desc is not required.
-        order_desc (bool): Descending or Ascending order
         limit (int/None): limit record count;
             If None, offset is not required.
         offset (int): record count per page
@@ -615,19 +699,12 @@ def build_sql_query(
     # Create fields
     sql_fields = ["`variants`.`id`"] + fields_to_sql(fields, use_as=True)
 
-    # if group_by:
-    #     sql_fields.insert(1, "COUNT() as 'count'")
-
     sql_query = f"SELECT DISTINCT {','.join(sql_fields)} "
 
-    # #Add child count if grouped
-    # if grouped:
-    #     sql_query += ", COUNT(*) as `children`"
-
     # Add source table
     sql_query += "FROM variants"
 
-    if is_annotation_join_required(fields, filters):
+    if is_annotation_join_required(fields, filters, order_by):
         sql_query += " LEFT JOIN annotations ON annotations.variant_id = variants.id"
 
     # Add Join Selection
@@ -638,21 +715,20 @@ def build_sql_query(
             f"INNER JOIN selections s ON s.id = sv.selection_id AND s.name = '{source}'"
         )
 
-    ## Create Sample Join
-    groupby = None
-
     # Test if sample*
     filters_fields = " ".join([list(i.keys())[0] for i in filters_to_flat(filters)])
-    if "samples.*." in filters_fields:
+
+    # Join all samples if $all or $any keywords are present
+    if "$all" in filters_fields or "$any" in filters_fields:
         join_samples = list(samples_ids.keys())
 
     else:
-        join_samples = samples_join_required(fields, filters)
+        join_samples = samples_join_required(fields, filters, order_by)
 
     for sample_name in join_samples:
         if sample_name in samples_ids:
             sample_id = samples_ids[sample_name]
-            sql_query += f""" INNER JOIN sample_has_variant `sample_{sample_name}` ON `sample_{sample_name}`.variant_id = variants.id AND `sample_{sample_name}`.sample_id = {sample_id}"""
+            sql_query += f""" LEFT JOIN genotypes `sample_{sample_name}` ON `sample_{sample_name}`.variant_id = variants.id AND `sample_{sample_name}`.sample_id = {sample_id}"""
 
     # Add Where Clause
     if filters:
@@ -660,23 +736,22 @@ def build_sql_query(
         if where_clause and where_clause != "()":
             sql_query += " WHERE " + where_clause
 
-    if groupby:
-        sql_query += groupby
-
-    # # Add Group By
-    # if group_by:
-    #     sql_query += " GROUP BY " + ",".join(fields_to_sql(group_by, use_as=False))
-    #     if having:
-    #         operator = having["op"]
-    #         val = having["value"]
-    #         sql_query += f" HAVING count {operator} {val}"
-
     # Add Order By
     if order_by:
         # TODO : sqlite escape field with quote
-        orientation = "DESC" if order_desc else "ASC"
-        order_by = ",".join(fields_to_sql(order_by))
-        sql_query += f" ORDER BY {order_by} {orientation}"
+
+        order_by_clause = []
+        for item in order_by:
+            field, direction = item
+
+            field = fields_to_sql([field])[0]
+
+            direction = "ASC" if direction else "DESC"
+            order_by_clause.append(f"{field} {direction}")
+
+        order_by_clause = ",".join(order_by_clause)
+
+        sql_query += f" ORDER BY {order_by_clause}"
 
     if limit:
         sql_query += f" LIMIT {limit} OFFSET {offset}"
@@ -688,6 +763,7 @@ def build_vql_query(
     fields,
     source="variants",
     filters={},
+    order_by=[],
     **kwargs,
 ):
 
@@ -700,4 +776,16 @@ def build_vql_query(
     else:
         where_clause = ""
 
-    return f"SELECT {select_clause} FROM {source}{where_clause}"
+    order_by_clause = ""
+    if order_by:
+        order_by_clause = []
+        for item in order_by:
+            field, direction = item
+            field = fields_to_vql([field])[0]
+            direction = "ASC" if direction else "DESC"
+            order_by_clause.append(f"{field} {direction}")
+
+        order_by_clause = " ORDER BY " + ",".join(order_by_clause)
+        print("YOUPU,", order_by_clause)
+
+    return f"SELECT {select_clause} FROM {source}{where_clause}{order_by_clause}"
