@@ -9,7 +9,7 @@ import re
 # Custom imports
 import cutevariant.commons as cm
 
-LOGGER = cm.logger()
+from cutevariant import LOGGER
 
 
 class BedReader:
