@@ -54,22 +54,22 @@ class VcfReader(AbstractReader):
         "snpeff3": SnpEffParser,
     }
 
-    def __init__(self, device, annotation_parser: str = None):
+    def __init__(self, filename, annotation_parser: str = None):
         """Construct a VCF Reader
 
         .. note::
             Number of lines `number_lines` AND `file_size` is computed in
             AbstractReader class.
 
-        :param device: File device handler returned by open.
+        :param filename: File filename handler returned by open.
         :key annotation_parser (str): "vep" or "snpeff"
             This argument forces the reader to use a specific parser for
             the annotations. By default it's None: no parser will be used,
             annotations will not be taken into account.
         """
         # Note: number of lines is computed in parent class
-        super().__init__(device)
-        vcf_reader = vcf.VCFReader(device, strict_whitespace=True, encoding="utf-8")
+        super().__init__(filename)
+        vcf_reader = vcf.VCFReader(filename=filename, strict_whitespace=True, encoding="utf-8")
         self.samples = vcf_reader.samples
         self.annotation_parser = None
         self.metadata = vcf_reader.metadata
@@ -77,8 +77,14 @@ class VcfReader(AbstractReader):
         # Fields descriptions
         self.fields = None
 
-        self.file_size = get_uncompressed_size(self.device.name)
-        self.compute_number_lines()
+        self.progress_every = 100
+        self.total_bytes = vcf_reader.total_bytes()
+        self.read_bytes = 0
+
+    def progress(self) -> float:
+        """override"""
+        progress = self.read_bytes / self.total_bytes * 100
+        return progress
 
     def get_fields(self):
         """Get full fields descriptions
@@ -163,9 +169,8 @@ class VcfReader(AbstractReader):
         :rtype: <generator <dict>>
         """
         # loop over record
-        self.device.seek(0)
         vcf_reader = vcf.VCFReader(
-            self.device, strict_whitespace=True, encoding="utf-8"
+            filename=self.filename, strict_whitespace=True, encoding="utf-8"
         )  # TODO use class attr
 
         # Genotype format fields
@@ -173,7 +178,9 @@ class VcfReader(AbstractReader):
         # Remove gt field (added manually later)
         format_fields.discard("gt")
 
-        for record in vcf_reader:
+        for i, record in enumerate(vcf_reader):
+
+            self.read_bytes = vcf_reader.read_bytes()
 
             # split row with multiple alt
             for index, alt in enumerate(record.ALT):
@@ -194,9 +201,7 @@ class VcfReader(AbstractReader):
                 for name in record.INFO:
                     if name.lower() not in forbidden_field:
                         if isinstance(record.INFO[name], list):
-                            variant[name.lower()] = ",".join(
-                                [str(i) for i in record.INFO[name]]
-                            )
+                            variant[name.lower()] = ",".join([str(i) for i in record.INFO[name]])
                         else:
                             variant[name.lower()] = record.INFO[name]
 
@@ -231,6 +236,8 @@ class VcfReader(AbstractReader):
 
                 yield variant
 
+        self.read_bytes = self.total_bytes
+
     def parse_fields(self):
         """Extract fields informations from VCF fields
 
@@ -293,10 +300,7 @@ class VcfReader(AbstractReader):
         }
 
         # Read VCF
-        self.device.seek(0)
-        vcf_reader = vcf.VCFReader(
-            self.device, strict_whitespace=True, encoding="utf-8"
-        )
+        vcf_reader = vcf.VCFReader(filename=self.filename, strict_whitespace=True, encoding="utf-8")
 
         # Read VCF INFO fields
         for field_name, info in vcf_reader.infos.items():
@@ -315,18 +319,18 @@ class VcfReader(AbstractReader):
         # Read VCF FORMAT fields
         for field_name, info in vcf_reader.formats.items():
             description = info.desc
+            field_type = VCF_TYPE_MAPPING[info.type]
 
             if field_name == "GT":
                 # Edit description of Genotype field
-                description += (
-                    " (0: homozygous_ref, 1: heterozygous, 2: homozygous_alt)"
-                )
+                description += " (0: homozygous_ref, 1: heterozygous, 2: homozygous_alt)"
+                field_type = VCF_TYPE_MAPPING["Integer"]
 
             yield {
                 "name": field_name.lower(),
                 "category": "samples",
                 "description": description,
-                "type": VCF_TYPE_MAPPING[info.type],
+                "type": field_type,
             }
 
     def get_samples(self):
@@ -347,7 +351,7 @@ class VcfReader(AbstractReader):
 
     def get_metadatas(self):
         """override from AbstractReader"""
-        output = {"filename": self.device.name}
+        output = {"filename": self.filename}
 
         for key, value in self.metadata.items():
             output[key] = str(value)
