@@ -9,9 +9,11 @@ For instance::
 See test_vql.py for usage and features.
 
 """
+
+
 import textx
 from pkg_resources import resource_string
-
+from typing import Tuple
 
 OPERATORS = {
     "=": "$eq",
@@ -21,11 +23,15 @@ OPERATORS = {
     "<=": "$lte",
     "IN": "$in",
     "!=": "$ne",
-    "NOT IN": "$nin",
-    "~": "$regex",
+    "!IN": "$nin",
+    "=~": "$regex",
+    "!~": "$nregex",
     "AND": "$and",
     "OR": "$or",
+    "ANY": "$any",
+    "ALL": "$all",
     "HAS": "$has",
+    "!HAS": "$nhas",
 }
 
 
@@ -64,9 +70,7 @@ class VQLSyntaxError(ValueError):
 
 
 # ============ Error handle ==================================
-def error_message_from_err(
-    err: textx.exceptions.TextXSyntaxError, raw_vql: str
-) -> (str, int):
+def error_message_from_err(err: textx.exceptions.TextXSyntaxError, raw_vql: str) -> Tuple[str, int]:
     """Return human-readable information and index in raw_sql query
     about the given exception"""
     # print(err)
@@ -110,7 +114,16 @@ class FilterTerm(metaclass=model_class):
 
         if isinstance(field, tuple):
             if field[0] == "samples":
-                field = f"samples.{field[1]}.{field[2]}"
+
+                name = field[1]
+
+                if field[1] in ("*", "ANY"):
+                    name = OPERATORS["ANY"]
+
+                if field[1] in ("?", "ALL"):
+                    name = OPERATORS["ALL"]
+
+                field = f"samples.{name}.{field[2]}"
 
         return {field: {op: val}}
 
@@ -157,6 +170,19 @@ class Tuple(metaclass=model_class):
         return list(self.items)
 
 
+class OrderBy(metaclass=model_class):
+    @property
+    def value(self):
+
+        print("DIRECTION", self.direction)
+        if not self.direction:
+            self.direction = "ASC"
+
+        direction = True if self.direction == "ASC" else False
+
+        return (self.field, direction)
+
+
 class WordSetIdentifier(metaclass=model_class):
     @property
     def value(self):
@@ -170,6 +196,8 @@ class SelectCmd(metaclass=model_class):
         filters = {}
         fields = []
 
+        order_by = [i.value for i in self.order_by]
+
         for col in self.fields:
             # Manage function like sample("boby").gt
             if isinstance(col, Function):
@@ -191,7 +219,12 @@ class SelectCmd(metaclass=model_class):
             "fields": fields,
             "source": self.source,
             "filters": filters,
+            "order_by": order_by,
         }
+
+        if order_by:
+            output["order_by"] = order_by
+
         return output
 
 
