@@ -1,7 +1,6 @@
 # Custom imports
 from cutevariant.core import command as cmd
 from cutevariant.core.querybuilder import build_sql_query
-import cutevariant.commons as cm
 
 from cutevariant import LOGGER
 
@@ -25,7 +24,7 @@ class AbstractWriter:
     def __init__(
         self,
         conn,
-        device,
+        filename,
         fields=["chr", "pos", "ref", "alt"],
         source="variants",
         filters={},
@@ -35,7 +34,7 @@ class AbstractWriter:
         self.source = source
         self.filters = filters
         self.conn = conn
-        self.device = device
+        self.filename = filename
 
     def async_save(self, *args, **kwargs):
         """
