@@ -3,8 +3,6 @@ import csv
 
 # Custom imports
 from .abstractwriter import AbstractWriter
-from cutevariant.core import command as cmd
-import cutevariant.commons as cm
 
 import time
 
@@ -27,12 +25,12 @@ class CsvWriter(AbstractWriter):
     def __init__(
         self,
         conn,
-        device,
+        filename,
         fields=["chr", "pos", "ref", "alt"],
         source="variants",
         filters={},
     ):
-        super().__init__(conn, device, fields, source, filters)
+        super().__init__(conn, filename, fields, source, filters)
 
         self.separator = "\t"
 
@@ -55,8 +53,11 @@ class CsvWriter(AbstractWriter):
         """
 
         # Use dictionnary to define proper arguments for the writer, beforehand, in one variable
+
+        device = open(self.filename, "w")
+
         dict_writer_options = {
-            "f": self.device,
+            "f": device,
             "delimiter": self.separator,
             "lineterminator": "\n",
         }
@@ -74,3 +75,5 @@ class CsvWriter(AbstractWriter):
             writer.writerow(written_var)
             # time.sleep(0.1) For demo purposes only. If the database is small, the progress bar won't show up !
             yield count
+
+        device.close()
