@@ -2,7 +2,7 @@
 import re
 
 # Qt imports
-from PySide2.QtGui import (
+from PySide6.QtGui import (
     QColor,
     QFont,
     QBrush,
@@ -12,14 +12,14 @@ from PySide2.QtGui import (
     QPalette,
     QPixmap,
 )
-from PySide2.QtCore import Qt, QModelIndex, QRect, QUrl, QPoint
-from PySide2.QtWidgets import QStyleOptionViewItem, QStyle
+from PySide6.QtCore import Qt, QModelIndex, QRect, QUrl, QPoint
+from PySide6.QtWidgets import QApplication, QStyleOptionViewItem, QStyle
 
 # Custom imports
 from cutevariant.gui.formatter import Formatter
 from cutevariant.gui import FIcon
+import cutevariant.constants as cst
 import cutevariant.commons as cm
-
 from cutevariant.config import Config
 
 
@@ -38,41 +38,45 @@ class CutestyleFormatter(Formatter):
         "frameshift_variant": "#ff89b5",
     }
 
-    ACMG_ICON = {
-        "0": FIcon(0xF03A1, "lightgray"),
-        "1": FIcon(0xF03A4, "#71e096"),
-        "2": FIcon(0xF03A7, "#a7ecbe"),
-        "3": FIcon(0xF03AA, "#f5a26f"),
-        "4": FIcon(0xF03AD, "#f9cdd1"),
-        "5": FIcon(0xF03B1, "#ed6d79"),
-    }
-
     IMPACT_COLOR = {
-        "HIGH": "#ff4b5c",
-        "LOW": "#056674",
-        "MODERATE": "#ecad7d",
-        "MODIFIER": "#ecad7d",
+        "HIGH": "#F15F74",
+        "LOW": "#98CB4A",
+        "MODERATE": "#F76D3C",
+        "MODIFIER": "#F76D2C",
     }
 
     FAV_ICON = {0: FIcon(0xF00C3), 1: FIcon(0xF00C0)}
 
     # Cache genotype icons
     # Values in gt field as keys (str), FIcon as values
-    GENOTYPE_ICONS = {key: FIcon(val) for key, val in cm.GENOTYPE_ICONS.items()}
+    GENOTYPE_ICONS = {key: FIcon(val) for key, val in cst.GENOTYPE_ICONS.items()}
 
     def __init__(self):
         self.refresh()
 
     def refresh(self):
-        config = Config("variant_view")
-        self.TAGS_COLOR = {tag["name"]: tag["color"] for tag in config.get("tags", [])}
+        # Tags colors
+        self.TAGS_COLOR = {}
+        config = Config("tags")
+        for tag in (
+            config.get("samples", []) + config.get("genotypes", []) + config.get("variants", [])
+        ):
+            self.TAGS_COLOR[tag["name"]] = tag["color"]
 
     def format(self, field: str, value: str, option, is_selected):
 
-        if value == "NULL":
+        if re.match(r"samples\..+\.gt", field) or field == "gt":
+            if value == "NULL":
+                value = -1
+            icon = cst.GENOTYPE_ICONS.get(int(value))
+            return {"text": "", "icon": FIcon(icon)}
+
+        if value == "NULL" or value == "None":
             font = QFont()
             font.setItalic(True)
-            return {"font": font, "color": "lightgray"}
+            color = option.palette.color(QPalette.BrightText if is_selected else QPalette.Text)
+            color = cm.contrast_color(color, factor=300)
+            return {"font": font, "color": color}
 
         if field == "ann.impact" and not is_selected:
             font = QFont()
@@ -81,28 +85,27 @@ class CutestyleFormatter(Formatter):
 
             return {"font": font, "color": color}
 
-        #     # Colour bases (default color is the one of the current theme)
-        if (field == "ref" or field == "alt") and (
-            value in ("A", "C", "G", "T") and not is_selected
-        ):
-            return {"color": self.BASE_COLOR.get(value)}
+        # #     # Colour bases (default color is the one of the current theme)
+        # if (field == "ref" or field == "alt") and (
+        #     value in ("A", "C", "G", "T") and not is_selected
+        # ):
+        #     return {"color": self.BASE_COLOR.get(value)}
 
         if field == "ann.gene" and not is_selected:
-            return {"color": "#6a9fca"}
-
-        if field == "classification":
-            icon = self.ACMG_ICON.get(str(value), self.ACMG_ICON["0"])
-            return {"icon": icon, "text": "", "icon-align": Qt.AlignCenter}
+            return {"color": QApplication.style().colors().get("blue", "blue")}
 
+        # if field == "classification":
+        #     icon = self.ACMG_ICON.get(str(value), self.ACMG_ICON["0"])
+        #     return {"icon": icon, "text": "", "icon-align": Qt.AlignCenter}
         if field == "rsid" and value.startswith("rs"):
             # font.setUnderline(True)
             return {"link": "http://www.google.fr"}
             # pen.setColor("#0068F7")
 
-        if field == "favorite":
-            icon = self.FAV_ICON.get(int(value), self.FAV_ICON[0])
-            return {"icon": icon, "text": "", "icon-align": Qt.AlignCenter}
-            return
+        # if field == "favorite":
+        #     icon = self.FAV_ICON.get(int(value), self.FAV_ICON[0])
+        #     return {"icon": icon, "text": "", "icon-align": Qt.AlignCenter}
+        #     return
 
         if field == "ann.hgvs_c":
             font = QFont()
@@ -120,26 +123,19 @@ class CutestyleFormatter(Formatter):
                 value = m.group(1)
                 return {"text": value}
 
-        if re.match(r"samples\..+\.gt", field):
-            icon = self.GENOTYPE_ICONS.get(int(value), self.GENOTYPE_ICONS[-1])
-            return {"text": "", "icon": icon}
-
         if field == "ann.consequence":
-            values = str(value).split("&")
+            values = str(value).split(cst.HAS_OPERATOR)
             font = QFont()
             metrics = QFontMetrics(font)
             x = 0
-            # y = option.rect.center().y()
             pix = QPixmap(option.rect.size())
             pix.fill(Qt.transparent)
             painter = QPainter(pix)
             for index, value in enumerate(values):
-                width = metrics.width(value)
+                width = metrics.boundingRect(value).width()
                 height = metrics.height()
                 rect = QRect(x, 2, width + 15, height + 10)
-
                 painter.setFont(font)
-                # painter.setClipRect(option.rect, Qt.IntersectClip)
                 painter.setBrush(QBrush(QColor(self.SO_COLOR.get(value, "#90d4f7"))))
                 painter.setPen(Qt.NoPen)
                 painter.drawRoundedRect(rect, 3, 3)
@@ -153,51 +149,26 @@ class CutestyleFormatter(Formatter):
             if value is None or value == "":
                 return {}
 
-            values = str(value).split("&")
+            values = str(value).split(cst.HAS_OPERATOR)
             font = QFont()
             metrics = QFontMetrics(font)
             x = 0
-            # y = option.rect.center().y()
             pix = QPixmap(option.rect.size())
             pix.fill(Qt.transparent)
             painter = QPainter(pix)
             for index, value in enumerate(values):
-                width = metrics.width(value)
+                width = metrics.boundingRect(value).width()
                 height = metrics.height()
-                rect = QRect(x, 2, width + 15, height + 10)
-
+                rect = QRect(x, (option.rect.height() - height) * 0.5, width + 10, height)
                 painter.setFont(font)
-                # painter.setClipRect(option.rect, Qt.IntersectClip)
-                painter.setBrush(
-                    QBrush(QColor(self.TAGS_COLOR.get(value, "lightgray")))
-                )
+                col = QColor(self.TAGS_COLOR.get(value, "#D5E9F5"))
+                painter.setBrush(QBrush(col))
                 painter.setPen(Qt.NoPen)
                 painter.drawRoundedRect(rect, 3, 3)
-                painter.setPen(QPen(QColor("white")))
+                painter.setPen(QPen(cm.contrast_color(col)))
                 painter.drawText(rect, Qt.AlignCenter | Qt.AlignVCenter, value)
-                x += width + 20
+                x += width + 15
 
             return {"pixmap": pix}
 
         return super().format(field, value, option, is_selected)
-
-    # def paint(
-    #     self, painter: QPainter, option: QStyleOptionViewItem, index: QModelIndex
-    # ):
-    #     """Apply graphical formatting to each item in each displayed column in the view"""
-    #     brush = QBrush()
-    #     pen = QPen()
-    #     font = QFont()
-
-    #     if option.state & QStyle.State_Selected:
-    #         text_color = option.palette.color(QPalette.Normal, QPalette.BrightText)
-    #     else:
-    #         text_color = option.palette.color(QPalette.Normal, QPalette.Text)
-
-    #     is_selected = option.state & QStyle.State_Selected
-
-    #     # Default theme color
-    #     pen.setColor(text_color)
-
-    #     field_name = self.field_name(index).lower()
-    #     value = self.value(index)
