@@ -4,7 +4,7 @@ from cutevariant.gui.formatter import Formatter
 
 class DefaultFormatter(Formatter):
 
-    DISPLAY_NAME = "Basic"
+    DISPLAY_NAME = "No style"
 
     def __init__(self):
         super().__init__()
