@@ -5,32 +5,48 @@ import sys
 import sqlite3
 import json
 import typing
+import re
 from pkg_resources import parse_version
 from functools import partial
 from logging import DEBUG
 
 # Qt imports
-from PySide2.QtCore import Qt, QSettings, QByteArray, QDir, QUrl, Signal, QSize
-from PySide2.QtWidgets import *
-from PySide2.QtGui import QIcon, QKeySequence, QDesktopServices
+from PySide6.QtCore import (
+    QEventLoop,
+    QStandardPaths,
+    Qt,
+    QSettings,
+    QByteArray,
+    QDir,
+    QUrl,
+    Signal,
+    QSize,
+    QPoint,
+)
+from PySide6.QtWidgets import *
+from PySide6.QtGui import QIcon, QKeySequence, QDesktopServices
 
 
 # Custom imports
 from cutevariant import LOGGER
-from cutevariant.core import get_sql_connection, get_metadatas, command
+from cutevariant.core import get_sql_connection, get_metadatas, command, querybuilder
 from cutevariant.core import sql
 from cutevariant.core.sql import get_database_file_name
 from cutevariant.core.writer import CsvWriter, PedWriter
+from cutevariant.core.quicksearch import quicksearch
 from cutevariant.gui import FIcon
-from cutevariant.gui.wizards import ProjectWizard
+from cutevariant.gui.widgets.project_wizard import ProjectWizard
+from cutevariant.gui.widgets.import_widget import VcfImportDialog
 from cutevariant.gui.settings import SettingsDialog
+from cutevariant.gui.widgets import SamplesEditor
 from cutevariant.gui.widgets.aboutcutevariant import AboutCutevariant
-from cutevariant import commons as cm
-from cutevariant.commons import (
+from cutevariant import constants as cst
+from cutevariant.constants import (
     MAX_RECENT_PROJECTS,
     DIR_ICONS,
     MIN_AUTHORIZED_DB_VERSION,
 )
+from cutevariant.config import Config
 
 from cutevariant.gui.export import ExportDialogFactory, ExportDialog
 
@@ -76,9 +92,11 @@ class StateData:
 
     def reset(self):
         self._data = {
-            "fields": ["favorite", "classification", "chr", "pos", "ref", "alt"],
+            "fields": ["chr", "pos", "ref", "alt"],
             "source": "variants",
             "filters": {},
+            "order_by": [],
+            "samples": [],
         }
 
 
@@ -119,13 +137,25 @@ class MainWindow(QMainWindow):
         self.toolbar = self.addToolBar("maintoolbar")
         self.toolbar.setObjectName("maintoolbar")  # For window saveState
         self.toolbar.setToolButtonStyle(Qt.ToolButtonTextBesideIcon)
+        self.toolbar.setFloatable(False)
+        self.toolbar.setMovable(False)
+        self.toolbar.setIconSize(QSize(20, 20))
+        self.plugin_toolbar = QToolBar("plugins")
+        self.plugin_toolbar.setObjectName("plugins_toolbar")
+        self.plugin_toolbar.setFloatable(False)
+        self.plugin_toolbar.setMovable(False)
+
+        self.addToolBar(Qt.LeftToolBarArea, self.plugin_toolbar)
 
         # Setup menu bar
         self.setup_actions()
 
         # Setup Central widget
         self.central_tab = QTabWidget()
+        self.central_tab.setTabBarAutoHide(True)
         self.footer_tab = QTabWidget()
+        self.footer_tab.setTabPosition(QTabWidget.South)
+        self.footer_tab.setTabBarAutoHide(True)
         self.vsplit = QSplitter(Qt.Vertical)
         self.vsplit.addWidget(self.central_tab)
         self.vsplit.addWidget(self.footer_tab)
@@ -139,21 +169,43 @@ class MainWindow(QMainWindow):
         self.status_bar = QStatusBar()
         self.setStatusBar(self.status_bar)
 
+        self.samples_info_label = QLabel()
+        self.filter_info_label = QLabel()
+        self.source_info_label = QLabel()
+        self.status_bar.addPermanentWidget(self.filter_info_label)
+
+        self.status_bar.addPermanentWidget(self.samples_info_label)
+        self.status_bar.addPermanentWidget(self.source_info_label)
+
+        # setup omnibar
+        self.quick_search_edit = QLineEdit()
+        self.quick_search_edit.setPlaceholderText("Type a gene or coordinate ...")
+        self.quick_search_edit.setMaximumWidth(400)
+        self.quick_search_edit.setContentsMargins(0, 0, 5, 0)
+        self.quick_search_edit.addAction(
+            FIcon(0xF0349), QLineEdit.TrailingPosition
+        ).triggered.connect(lambda: self.quick_search(self.quick_search_edit.text()))
+        self.quick_search_edit.returnPressed.connect(
+            lambda: self.quick_search(self.quick_search_edit.text())
+        )
+
+        search_bar = self.addToolBar("Search")
+        search_bar.addWidget(self.quick_search_edit)
+
         # Window geometry
         self.resize(600, 400)
-        self.setGeometry(
-            QApplication.instance().desktop().rect().adjusted(100, 100, -100, -100)
-        )
+        # self.setGeometry(
+        #     QApplication.instance().desktop().rect().adjusted(100, 100, -100, -100)
+        # )
 
         # If True, the GUI settings are deleted when the app is closed
         self.requested_reset_ui = False
         # Restores the state of this mainwindow's toolbars and dockwidgets
         self.read_settings()
 
-        # Auto open recent projects
-        recent = self.get_recent_projects()
-        if recent and os.path.isfile(recent[0]):
-            self.open(recent[0])
+        # To avoid refreshing side effects upon project opening
+        self._project_is_opening = False
+        self._is_initialize = True
 
     def set_state_data(self, key: str, value: typing.Any):
         """set state data value from key
@@ -195,18 +247,27 @@ class MainWindow(QMainWindow):
             area: Area location. Defaults to Qt.LeftDockWidgetArea.
         """
         dock = QDockWidget()
-        dock.setWindowTitle(widget.windowTitle())
+        dock.setWindowTitle(widget.windowTitle().upper())
+        dock.setStyleSheet("QDockWidget::title {text-align:center;} QDockWidget{font-weight:bold;}")
+        # frame = QLabel()
+        # frame.setAlignment(Qt.AlignCenter)
+        # frame.setText("<b>" + dock.windowTitle() + "</b>")
         dock.setWidget(widget)
-        dock.setStyleSheet("QDockWidget { font: bold }")
+        # noneWidget = QWidget()
+        # dock.setTitleBarWidget(frame)
         # Keep the attached dock to allow further clean deletion
         widget.dock = dock
         # Set the objectName for a correct restoration after saveState
         dock.setObjectName(str(widget.__class__))
-
+        self.plugin_toolbar.addAction(dock.toggleViewAction())
         self.addDockWidget(area, dock)
         action = dock.toggleViewAction()
         action.setIcon(widget.windowIcon())
         action.setText(widget.windowTitle())
+        action.setToolTip(widget.toolTip())
+        action.setWhatsThis(widget.whatsThis())
+
+        action.triggered.connect(widget.on_refresh)
         self.view_menu.addAction(action)
 
         return dock
@@ -250,8 +311,7 @@ class MainWindow(QMainWindow):
 
             if not widget.objectName():
                 LOGGER.debug(
-                    "widget '%s' has no objectName attribute; "
-                    "=> fallback to extension name",
+                    "widget '%s' has no objectName attribute; " "=> fallback to extension name",
                     displayed_title,
                 )
                 widget.setObjectName(name)
@@ -260,10 +320,10 @@ class MainWindow(QMainWindow):
             widget.setWindowTitle(displayed_title)
 
             # WhatsThis content
-            long_description = extension.get("long_description")
-            if not long_description:
-                long_description = extension.get("description")
+            long_description = extension.get("long_description", "")
+            short_description = extension.get("description", "")
             widget.setWhatsThis(long_description)
+            widget.setToolTip(short_description)
             # Register (launch first init on some of them)
             widget.mainwindow = self
             widget.on_register(self)
@@ -298,7 +358,7 @@ class MainWindow(QMainWindow):
             self.dialog_plugins[dialog_action] = plugin_dialog_class
             dialog_action.triggered.connect(self.show_dialog)
 
-    def refresh_plugins(self, sender: plugin.PluginWidget = None):
+    def refresh_plugins(self, sender: plugin.PluginWidget = None, force_refresh=False):
         """Refresh all widget plugins
 
         It doesn't refresh a plugin if :
@@ -315,8 +375,9 @@ class MainWindow(QMainWindow):
         for plugin_obj in self.plugins.values():
             need_refresh = (
                 plugin_obj is not sender
-                and (plugin_obj.isVisible() or not plugin_obj.REFRESH_ONLY_VISIBLE)
+                and (plugin_obj.isVisible() or force_refresh or not plugin_obj.REFRESH_ONLY_VISIBLE)
                 and (set(plugin_obj.REFRESH_STATE_DATA) & self._state_data.changed)
+                and not self._project_is_opening
             )
 
             if need_refresh:
@@ -333,6 +394,8 @@ class MainWindow(QMainWindow):
         for plugin in plugin_to_refresh:
             plugin.on_refresh()
 
+        self.update_status_bar()
+
     def refresh_plugin(self, plugin_name: str):
         """Refresh a widget plugin identified by plugin_name
 
@@ -354,24 +417,37 @@ class MainWindow(QMainWindow):
         ## File Menu
         self.file_menu = self.menuBar().addMenu(self.tr("&File"))
         self.new_project_action = self.file_menu.addAction(
-            FIcon(0xF01BA), self.tr("&New project"), self.new_project, QKeySequence.New
+            FIcon(0xF0415), self.tr("&New project"), self.new_project, QKeySequence.New
         )
         self.open_project_action = self.file_menu.addAction(
-            FIcon(0xF095D),
+            FIcon(0xF0DCF),
             self.tr("&Open project..."),
             self.open_project,
             QKeySequence.Open,
         )
+        self.import_file_action = self.file_menu.addAction(
+            FIcon(0xF102F),
+            self.tr("&Import file"),
+            self.import_file,
+            QKeySequence.AddTab,
+        )
 
         self.toolbar.addAction(self.new_project_action)
         self.toolbar.addAction(self.open_project_action)
-        self.toolbar.addAction(
-            FIcon(0xF02D7), self.tr("Help"), QWhatsThis.enterWhatsThisMode
-        )
+        self.toolbar.addAction(self.import_file_action)
+        # sample_action = self.toolbar.addAction(
+        #     FIcon(0xF0010), self.tr("Add Sample(s)"), self.on_select_samples
+        # )
+        # sample_action.setToolTip(self.tr("Add samples to the current selection"))
+
+        # self.toolbar.addAction(self.open_config_action)
+        # self.toolbar.addAction(FIcon(0xF0625), self.tr("Help"), QWhatsThis.enterWhatsThisMode)
         self.toolbar.addSeparator()
 
         ### Recent projects
+        self.file_menu.addSeparator()
         self.recent_files_menu = self.file_menu.addMenu(self.tr("Open recent"))
+        self.file_menu.addSeparator()
 
         self.setup_recent_menu()
 
@@ -394,19 +470,19 @@ class MainWindow(QMainWindow):
 
         self.file_menu.addSeparator()
 
+        self.file_menu.addAction(FIcon(0xF0193), self.tr("Save session ..."), self.on_save_session)
         self.file_menu.addAction(
-            FIcon(0xF0193), self.tr("Save session ..."), self.save_session
-        )
-        self.file_menu.addAction(
-            FIcon(0xF0770), self.tr("Restore session ..."), self.load_session
+            FIcon(0xF0770), self.tr("Restore session ..."), self.on_load_session
         )
 
         self.file_menu.addSeparator()
         ### Misc
-        self.file_menu.addAction(
-            FIcon(0xF0493), self.tr("Settings..."), self.show_settings
-        )
+
+        self.file_menu.addAction(FIcon(0xF0493), self.tr("Settings..."), self.show_settings)
         self.file_menu.addSeparator()
+        self.close_project_action = self.file_menu.addAction(
+            FIcon(0xF0156), self.tr("&Close project"), self.close_database
+        )
         self.file_menu.addAction(self.tr("&Quit"), self.close, QKeySequence.Quit)
 
         ## Edit
@@ -421,7 +497,7 @@ class MainWindow(QMainWindow):
         self.edit_menu.addSeparator()
         self.edit_menu.addAction(
             FIcon(0xF0486),
-            self.tr("&Select all variants"),
+            self.tr("&Select all displayed variants"),
             self.select_all_variants,
             QKeySequence.SelectAll,
         )
@@ -430,9 +506,7 @@ class MainWindow(QMainWindow):
         self.view_menu = self.menuBar().addMenu(self.tr("&View"))
         self.view_menu.addAction(self.tr("Reset widgets positions"), self.reset_ui)
         # Set toggle footer visibility action
-        show_action = self.view_menu.addAction(
-            FIcon(0xF018D), self.tr("Show VQL editor")
-        )
+        show_action = self.view_menu.addAction(FIcon(0xF018D), self.tr("Show VQL editor"))
         show_action.setCheckable(True)
         self.toolbar.addAction(show_action)
         show_action.setChecked(True)
@@ -465,14 +539,12 @@ class MainWindow(QMainWindow):
         self.help_menu.addAction(
             FIcon(0xF059F),
             self.tr("Documentation..."),
-            partial(QDesktopServices.openUrl, QUrl(cm.WIKI_URL, QUrl.TolerantMode)),
+            partial(QDesktopServices.openUrl, QUrl(cst.WIKI_URL, QUrl.TolerantMode)),
         )
         self.help_menu.addAction(
             FIcon(0xF0A30),
             self.tr("Report a bug..."),
-            partial(
-                QDesktopServices.openUrl, QUrl(cm.REPORT_BUG_URL, QUrl.TolerantMode)
-            ),
+            partial(QDesktopServices.openUrl, QUrl(cst.REPORT_BUG_URL, QUrl.TolerantMode)),
         )
 
         self.help_menu.addSeparator()
@@ -481,16 +553,14 @@ class MainWindow(QMainWindow):
         self.setup_developers_menu()
         self.help_menu.addMenu(self.developers_menu)
 
-        self.help_menu.addAction(
-            self.tr("About Qt..."), QApplication.instance().aboutQt
-        )
+        self.help_menu.addAction(self.tr("About Qt..."), QApplication.instance().aboutQt)
         self.help_menu.addAction(
             QIcon(DIR_ICONS + "app.png"),
             self.tr("About Cutevariant..."),
             self.about_cutevariant,
         )
 
-    def open(self, filepath):
+    def open_database_from_file(self, filepath):
         """Open the given db/project file
 
         .. note:: Called at the end of a project creation by the Wizard,
@@ -511,17 +581,13 @@ class MainWindow(QMainWindow):
         try:
             # DB version filter
             db_version = get_metadatas(self.conn).get("cutevariant_version")
-            if db_version and parse_version(db_version) < parse_version(
-                MIN_AUTHORIZED_DB_VERSION
-            ):
+            if db_version and parse_version(db_version) < parse_version(MIN_AUTHORIZED_DB_VERSION):
                 # Refuse to open blacklisted DB versions
                 # Unversioned files are still accepted
                 QMessageBox.critical(
                     self,
                     self.tr("Error while opening project"),
-                    self.tr("File: {} is too old; please create a new project.").format(
-                        filepath
-                    ),
+                    self.tr("File: {} is too old; please create a new project.").format(filepath),
                 )
                 return
 
@@ -533,9 +599,7 @@ class MainWindow(QMainWindow):
             QMessageBox.critical(
                 self,
                 self.tr("Error while opening project"),
-                self.tr("File: {}\nThe following exception occurred:\n{}").format(
-                    filepath, e
-                ),
+                self.tr("File: {}\nThe following exception occurred:\n{}").format(filepath, e),
             )
             return
 
@@ -549,9 +613,10 @@ class MainWindow(QMainWindow):
         Args:
             conn (sqlite3.Connection): Sqlite3 Connection
         """
+
         self.conn = conn
 
-        self._state_data.reset()
+        # self._state_data.reset()
 
         # Clear memoization cache for count_cmd
         sql.clear_lru_cache()
@@ -563,9 +628,24 @@ class MainWindow(QMainWindow):
 
         # self.state = self.app_settings.value(f"{file_path}/last_state", State())
 
+        self._project_is_opening = True
         for plugin_obj in self.plugins.values():
             plugin_obj.on_open_project(self.conn)
             plugin_obj.setEnabled(True)
+        self._project_is_opening = False
+
+    def close_database(self):
+        if self.conn:
+            self.conn.close()
+            self._state_data.reset()
+            self.setWindowTitle("Cutevariant")
+
+            for plugin_obj in self.plugins.values():
+                plugin_obj.on_close_project()
+                plugin_obj.setEnabled(False)
+
+        self.samples_info_label.clear()
+        self.filter_info_label.clear()
 
     def save_recent_project(self, path):
         """Save current project into QSettings
@@ -613,7 +693,7 @@ class MainWindow(QMainWindow):
     def on_recent_project_clicked(self):
         """Slot to load a recent project"""
         action = self.sender()
-        self.open(action.text())
+        self.open_database_from_file(action.text())
 
     def new_project(self):
         """Slot to allow creation of a project with the Wizard"""
@@ -621,18 +701,34 @@ class MainWindow(QMainWindow):
         if not wizard.exec_():
             return
 
-        db_filename = (
-            wizard.field("project_path")
-            + QDir.separator()
-            + wizard.field("project_name")
-            + ".db"
-        )
+        db_filename = wizard.db_filename()
+
         try:
-            self.open(db_filename)
+            self.open_database_from_file(db_filename)
         except Exception as e:
             self.status_bar.showMessage(e.__class__.__name__ + ": " + str(e))
             raise
 
+    def on_select_samples(self):
+
+        w = SamplesEditor(self.conn)
+        w.setAttribute(Qt.WA_DeleteOnClose)
+        w.setWindowModality(Qt.ApplicationModal)
+        loop = QEventLoop()
+        w.destroyed.connect(loop.quit)
+        w.sample_selected.connect(self.add_samples)
+        w.move(
+            self.geometry().center() - QPoint(w.geometry().width() / 2, w.geometry().height() / 2)
+        )
+        w.show()
+        loop.exec()
+
+    def add_samples(self, samples: list):
+
+        samples = set(self.get_state_data("samples")).union(set(samples))
+        self.set_state_data("samples", list(samples))
+        self.refresh_plugins()
+
     def open_project(self):
         """Slot to open an already existing project from a QFileDialog"""
         # Reload last directory used
@@ -646,11 +742,27 @@ class MainWindow(QMainWindow):
         )
         if filepath:
             try:
-                self.open(filepath)
+                self.open_database_from_file(filepath)
             except Exception as e:
                 self.status_bar.showMessage(e.__class__.__name__ + ": " + str(e))
                 raise
 
+    def import_file(self):
+        """Slot to allow update of a project with a Wizard"""
+
+        # Todo .. variable of file
+        dialog = VcfImportDialog(sql.get_database_file_name(self.conn))
+
+        if dialog.exec_() == QDialog.Accepted:
+
+            db_filename = dialog.db_filename()
+            # LOGGER.warning("ICI", db_filename)
+
+            try:
+                self.open_database_from_file(db_filename)
+            except Exception as e:
+                self.status_bar.showMessage(e.__class__.__name__ + ": " + str(e))
+
     def export_as_csv(self):
         """Export variants into CSV file"""
         # Reload last directory used
@@ -795,7 +907,14 @@ class MainWindow(QMainWindow):
     def select_all_variants(self):
         """Select all elements in the current tab's view"""
         if "variant_view" in self.plugins:
-            self.plugins["variant_view"].select_all()
+            self.plugins["variant_view"].view.select_all()
+
+    def get_last_session_path(self):
+        return QDir(
+            QStandardPaths.writableLocation(QStandardPaths.ConfigLocation)
+            + QDir.separator()
+            + "cutevariant"
+        ).absoluteFilePath("last.session.json")
 
     def closeEvent(self, event):
         """Save the current state of this mainwindow's toolbars and dockwidgets
@@ -807,13 +926,15 @@ class MainWindow(QMainWindow):
         """
         self.write_settings()
 
+        # Save session
+        self.save_session(self.get_last_session_path())
+
         # Don't forget to tell all the plugins that the window is being closed
         for plugin_obj in self.plugins.values():
             plugin_obj.on_close()
         super().closeEvent(event)
 
-    def save_session(self):
-        """save plugin state into a json file"""
+    def on_save_session(self):
 
         filename, _ = QFileDialog.getSaveFileName(
             self,
@@ -822,6 +943,9 @@ class MainWindow(QMainWindow):
             "Session file (*.session.json)",
         )
 
+        if not filename.endswith(".session.json"):
+            filename = filename + ".session.json"
+
         if os.path.exists(filename):
             ret = QMessageBox.warning(
                 self,
@@ -833,22 +957,12 @@ class MainWindow(QMainWindow):
             if ret == QMessageBox.No:
                 return
 
-        if not filename.endswith(".session.json"):
-            filename = filename + ".session.json"
+        self.save_session(filename)
 
-        #  write sessions
-        session = {}
-        for name, plugin in self.plugins.items():
-            session[name] = plugin.to_json()
-
-        #  write file
-        with open(filename, "w") as file:
-            json.dump(session, file)
-
-    def load_session(self):
+    def on_load_session(self):
         filename, _ = QFileDialog.getOpenFileName(
             self,
-            self.tr("Save the session"),
+            self.tr("Load the session"),
             QDir.home().path(),
             "Session file (*.session.json)",
         )
@@ -856,14 +970,59 @@ class MainWindow(QMainWindow):
         if not os.path.exists(filename):
             return
 
+        self.load_session(filename)
+
+    def save_session(self, filename: str):
+        """save plugin state into a json file"""
+
+        session = {
+            "db_path": sql.get_database_file_name(self.conn),
+            "fields": self.get_state_data("fields"),
+            "source": self.get_state_data("source"),
+            "filters": self.get_state_data("filters"),
+            "order_by": self.get_state_data("order_by"),
+            "samples": self.get_state_data("samples"),
+        }
+
+        # save plugins
+        session["plugins"] = {}
+        for name, plugin in self.plugins.items():
+            session["plugins"][name] = plugin.to_json()
+
+        with open(filename, "w") as file:
+            json.dump(session, file)
+
+    def showEvent(self, event):
+
+        # Execute first run
+        if self._is_initialize:
+            path = self.get_last_session_path()
+            if os.path.isfile(path):
+                self.load_session(path)
+
+        self._is_initialize = False
+        return super().showEvent(event)
+
+    def load_session(self, filename: str):
+
         # read sessions
         with open(filename) as file:
             state = json.load(file)
 
-        #  set plugins
-        for name, plugin in self.plugins.items():
-            if name in state:
-                plugin.from_json(state[name])
+        if "db_path" in state:
+
+            self.set_state_data("fields", state.get("fields", []))
+            self.set_state_data("source", state.get("source", "variants"))
+            self.set_state_data("filters", state.get("filters", {}))
+            self.set_state_data("order_by", state.get("order_by", []))
+            self.set_state_data("samples", state.get("samples", []))
+
+            if "plugins" in state:
+                for name, plugin in self.plugins.items():
+                    if name in state["plugins"]:
+                        plugin.from_json(state["plugins"][name])
+
+            self.open_database_from_file(state["db_path"])
 
     def write_settings(self):
         """Store the state of this mainwindow.
@@ -899,7 +1058,7 @@ class MainWindow(QMainWindow):
     def toggle_footer_visibility(self, visibility):
         """Toggle visibility of the bottom toolbar and all its plugins"""
         # self.footer_tab.setVisible(visibility)
-        if visibility:
+        if not visibility:
             self.vsplit.setSizes([100, 0])
         else:
             self.vsplit.setSizes([200, 100])
@@ -955,9 +1114,7 @@ class MainWindow(QMainWindow):
         ]  # Hacky, extracts extension from second element from getSaveFileName result
 
         # Automatic extension of file_name
-        file_name = (
-            file_name if file_name.endswith(chosen_ext) else f"{file_name}.{chosen_ext}"
-        )
+        file_name = file_name if file_name.endswith(chosen_ext) else f"{file_name}.{chosen_ext}"
 
         export_dialog: ExportDialog = ExportDialogFactory.create_dialog(
             self.conn,
@@ -1000,6 +1157,47 @@ class MainWindow(QMainWindow):
 
         return self.developers_menu
 
+    def update_status_bar(self):
+
+        source = self.get_state_data("source")
+        fields = self.get_state_data("fields")
+        filters = self.get_state_data("filters")
+        samples = self.get_state_data("samples")
+        order_by = self.get_state_data("order_by")
+
+        vql = querybuilder.filters_to_vql(filters)
+        if not vql:
+            vql = "None"
+
+        vql = "Filters: " + vql
+
+        # self.filter_info_label.setText(vql)
+
+        count = len(samples)
+        self.samples_info_label.setText(f"Samples: {count}")
+        self.samples_info_label.setToolTip("<br/>".join(samples))
+        self.source_info_label.setText(f"Source: {source}")
+
+    def quick_search(self, query: str):
+
+        additionnal_filter = quicksearch(query)
+        self.quick_search_edit.clear()
+
+        if additionnal_filter:
+            previous_filter = copy.deepcopy(self.get_state_data("filters"))
+
+            # TODO: do we really need to extend filters ?
+            # if "$and" in previous_filter:
+            #     previous_filter["$and"].extend(additionnal_filter["$and"])
+
+            previous_filter = additionnal_filter
+
+            self.set_state_data(
+                "filters",
+                previous_filter,
+            )
+            self.refresh_plugins()
+
     # @Slot()
     # def on_query_model_changed(self):
     #     for name, _plugin in self.plugins.items():
