@@ -1,18 +1,20 @@
 ## ================= Settings widgets ===================
 # Qt imports
-from cutevariant.gui.plugins.harmonizome_wordset import dialogs
 from typing import List
-from PySide2.QtCore import *
-from PySide2.QtGui import QColor, QFont, QIcon, QPixmap
-from PySide2.QtWidgets import *
+from PySide6.QtCore import *
+from PySide6.QtGui import QColor, QFont, QIcon, QPixmap
+from PySide6.QtWidgets import *
 
 # Custom imports
 from cutevariant.gui.plugin import PluginSettingsWidget
 from cutevariant.gui.settings import AbstractSettingsWidget
 from cutevariant.gui import FIcon
-import cutevariant.commons as cm
+import cutevariant.constants as cst
 from cutevariant.config import Config
 
+from cutevariant.gui.widgets import ClassificationEditor
+
+
 import typing
 import copy
 
@@ -166,205 +168,6 @@ class LinksModel(QAbstractListModel):
             return QIcon(FIcon(0xF0866))
 
 
-class TagModel(QAbstractListModel):
-    def __init__(self, parent: QObject = None) -> None:
-        super().__init__(parent=parent)
-        self.items = []
-
-    def data(self, index: QModelIndex, role: int) -> typing.Any:
-        if role == Qt.DisplayRole:
-            return self.items[index.row()]["name"]
-        if role == Qt.ToolTipRole:
-            return self.items[index.row()]["description"]
-        if role == Qt.DecorationRole:
-            # Color is stored as a string to help with serialization
-            return QColor(self.items[index.row()]["color"])
-
-    def setData(self, index: QModelIndex, value: typing.Any, role: int) -> bool:
-        if role == Qt.DisplayRole:
-            self.items[index.row()]["name"] = value
-        if role == Qt.ToolTipRole:
-            self.items[index.row()]["description"] = value
-        if role == Qt.DecorationRole:
-            # Color is stored as a string to help with serialization
-            self.items[index.row()]["color"] = value
-
-        self.dataChanged.emit(index, index)
-
-    def add_item(self, item: dict):
-        self.beginInsertRows(QModelIndex(), self.rowCount(), self.rowCount() + 1)
-        self.items.append(copy.deepcopy(item))
-        self.endInsertRows()
-
-    def rowCount(self, parent: QModelIndex = QModelIndex()) -> int:
-        return len(self.items)
-
-    def remove_rows(self, indexes: typing.List[QModelIndex]):
-        self.beginResetModel()
-        indexes = sorted(indexes, reverse=True)
-        for idx in indexes:
-            data = {
-                "name": idx.data(Qt.DisplayRole),
-                "description": idx.data(Qt.ToolTipRole),
-                "color": idx.data(Qt.DecorationRole),
-            }
-            self.items.remove(data)
-        self.endResetModel()
-
-    def clear(self):
-        self.beginResetModel()
-        self.items.clear()
-        self.endResetModel()
-
-
-class TagDialog(QDialog):
-    def __init__(
-        self, name="", description="", color="#FF00FF", parent: QWidget = None
-    ) -> None:
-        super().__init__(parent=parent)
-
-        self.setWindowTitle(self.tr("Edit tag"))
-
-        self._layout = QVBoxLayout(self)
-
-        self._button_box = QDialogButtonBox(
-            QDialogButtonBox.Ok | QDialogButtonBox.Cancel
-        )
-        self._button_box.accepted.connect(self.accept)
-        self._button_box.rejected.connect(self.reject)
-
-        self.form_layout = QFormLayout()
-        self.tag_le = QLineEdit(self)
-        self.descr_le = QLineEdit(self)
-        self.color_pick = QPushButton(self.tr("Pick color..."), self)
-        self.color = QColor("#FF0000")
-
-        self.tag_le.setPlaceholderText(self.tr("Name"))
-        self.descr_le.setPlaceholderText(self.tr("Description"))
-        self.color = QColor("red")
-
-        # When we click, we change tag's color
-        self.color_pick.clicked.connect(self._get_tag_color)
-
-        self.form_layout.addRow(self.tr("Name"), self.tag_le)
-        self.form_layout.addRow(self.tr("Description"), self.descr_le)
-        self.form_layout.addRow(self.tr("Color"), self.color_pick)
-
-        self._layout.addLayout(self.form_layout)
-        self._layout.addWidget(self._button_box)
-
-        self.set_tag(name, description, color)
-
-    def set_tag(self, name: str = "", description: str = "", color: str = "#FF00FF"):
-        """Set tag
-
-        Args:
-            name (str, optional):
-            description (str, optional):
-            color (str, optional):
-        """
-        self.tag_le.setText(name)
-        self.descr_le.setText(description)
-        self.color = color
-        self.color_pick.setIcon(FIcon(0xF0765, QColor(self.color)))
-
-    def get_tag(self) -> dict:
-        """Summary
-
-        Returns:
-            dict: return name, description, color
-        """
-
-        return {
-            "name": self.tag_le.text(),
-            "description": self.descr_le.text(),
-            "color": self.color,
-        }
-
-    def _get_tag_color(self):
-        color = QColorDialog.getColor(QColor(self.color), self.color_pick).name()
-
-        if color:
-            current_tag = self.get_tag()
-            current_tag["color"] = color
-            self.set_tag(**current_tag)
-
-
-class TagsSettings(AbstractSettingsWidget):
-    def __init__(self):
-        super().__init__()
-
-        self.setWindowTitle("Tags")
-        self.label = QLabel(
-            """
-            Set tags available
-            """
-        )
-        self.setWindowIcon(FIcon(0xF12F7))
-        self.view = QListView()
-        self.model = TagModel()
-
-        self.view.setModel(self.model)
-        self.view.setSelectionMode(QAbstractItemView.ExtendedSelection)
-
-        self.add_button = QPushButton(self.tr("Add"))
-        self.rem_button = QPushButton(self.tr("Remove"))
-        self.clear_button = QPushButton(self.tr("Clear"))
-        self.edit_button = QPushButton(self.tr("Edit"))
-
-        h_layout = QHBoxLayout(self)
-        h_layout.addWidget(self.view)
-        v_layout = QVBoxLayout()
-        v_layout.addWidget(self.add_button)
-        v_layout.addWidget(self.edit_button)
-        v_layout.addWidget(self.rem_button)
-        v_layout.addStretch()
-        v_layout.addWidget(self.clear_button)
-        h_layout.addLayout(v_layout)
-
-        self.add_button.clicked.connect(self.on_add)
-        self.rem_button.clicked.connect(self.on_rem)
-        self.clear_button.clicked.connect(self.on_clear)
-        self.edit_button.clicked.connect(self.on_edit)
-
-    def save(self):
-
-        config = self.section_widget.create_config()
-        config["tags"] = self.model.items
-        config.save()
-
-    def load(self):
-        config: Config = self.section_widget.create_config()
-        tags = config.get("tags", [])
-        if isinstance(tags, list):
-            if all(isinstance(tag, dict) for tag in tags):
-                self.model.items = tags
-
-    def on_add(self):
-        dialog = TagDialog(parent=self)
-        if dialog.exec_() == QDialog.Accepted:
-            self.model.add_item(dialog.get_tag())
-
-    def on_edit(self):
-        index = self.view.currentIndex()
-        name = index.data(Qt.DisplayRole)
-        description = index.data(Qt.ToolTipRole)
-        color = index.data(Qt.DecorationRole).name()
-        dialog = TagDialog(name, description, color)
-
-        if dialog.exec_() == QDialog.Accepted:
-            tag = dialog.get_tag()
-            self.model.setData(index, tag["name"], Qt.DisplayRole)
-            self.model.setData(index, tag["description"], Qt.ToolTipRole)
-            self.model.setData(index, tag["color"], Qt.DecorationRole)
-
-    def on_rem(self):
-        self.model.remove_rows(self.view.selectionModel().selectedRows())
-
-    def on_clear(self):
-        self.model.clear()
-
-
 class GeneralSettings(AbstractSettingsWidget):
     def __init__(self):
         super().__init__()
@@ -419,9 +222,7 @@ class LinkSettings(AbstractSettingsWidget):
         self.set_default_button.setToolTip(self.tr("Double click will open this link"))
         self.remove_button = QPushButton(self.tr("Remove"))
 
-        self.batch_open_cb = QCheckBox(
-            self.tr("Allow batch opening of all selected variants")
-        )
+        self.batch_open_cb = QCheckBox(self.tr("Allow batch opening of all selected variants"))
 
         v_layout = QVBoxLayout()
         v_layout.addWidget(self.add_button)
@@ -487,7 +288,7 @@ class LinkSettings(AbstractSettingsWidget):
                 """<p>Create a link using variant fields as placeholders with <a href='https://jinja.palletsprojects.com/en/3.0.x/'>jinja2</a> syntax.<br/> 
 <b>For instance: </b> <br/>
 <code>https://genome.ucsc.edu/cgi-bin/hgTracks?db=hg19&position={{chr}}:{{pos}}</code><br/>
-<code>https://www.google.fr?q={{ann[0].gene}}</code><br/>
+<code>https://www.google.fr?q={{annotations[0].gene}}</code><br/>
 <code>https://www.google.fr?q={{chr|replace('chr','')}}</code>
  </p>
             """
@@ -517,9 +318,7 @@ class LinkSettings(AbstractSettingsWidget):
             # Fill forms with item data
             name.setText(index.data(Qt.DisplayRole))
             url.setText(index.data(Qt.ToolTipRole))
-            is_browser = (
-                Qt.Checked if bool(index.data(Qt.UserRole + 1)) else Qt.Unchecked
-            )
+            is_browser = Qt.Checked if bool(index.data(Qt.UserRole + 1)) else Qt.Unchecked
             browser.setChecked(is_browser)
 
         # Also do a minimal check on the data inserted
@@ -532,9 +331,7 @@ class LinkSettings(AbstractSettingsWidget):
                 )
             else:
                 # Add the item to the list
-                self.link_model.add_link(
-                    name.text(), url.text(), bool(browser.checkState()), False
-                )
+                self.link_model.add_link(name.text(), url.text(), bool(browser.checkState()), False)
 
             # Save the item in settings
             # (Here to limit the friction with Save all button)
@@ -586,6 +383,29 @@ class MemorySettings(AbstractSettingsWidget):
         pass
 
 
+class ClassificationSettings(AbstractSettingsWidget):
+    def __init__(self):
+        super().__init__()
+        self.setWindowTitle(self.tr("Classification"))
+        # self.setWindowIcon(FIcon(0xF070F))
+
+        layout = QVBoxLayout(self)
+        self.w = ClassificationEditor()
+        layout.addWidget(self.w)
+
+    def save(self):
+        """override"""
+        config = self.section_widget.create_config()
+        config["classifications"] = self.w.get_classifications()
+        config.save()
+
+    def load(self):
+        """override"""
+        config = self.section_widget.create_config()
+        classifications = config.get("classifications", [])
+        self.w.set_classifications(classifications)
+
+
 class VariantViewSettingsWidget(PluginSettingsWidget):
     """Instantiated plugin in the settings panel of Cutevariant
 
@@ -601,4 +421,4 @@ class VariantViewSettingsWidget(PluginSettingsWidget):
         self.setWindowTitle("Variant view")
         self.add_page(GeneralSettings())
         self.add_page(LinkSettings())
-        self.add_page(TagsSettings())
+        self.add_page(ClassificationSettings())
