@@ -13,8 +13,8 @@ from textx.exceptions import TextXSyntaxError
 import sqlite3
 
 # Qt imports
-from PySide2.QtCore import Qt, QStringListModel
-from PySide2.QtWidgets import (
+from PySide6.QtCore import Qt, QStringListModel
+from PySide6.QtWidgets import (
     QToolBar,
     QCompleter,
     QVBoxLayout,
@@ -22,7 +22,7 @@ from PySide2.QtWidgets import (
     QFrame,
     QApplication,
 )
-from PySide2.QtGui import QKeySequence
+from PySide6.QtGui import QKeySequence
 
 # Custom imports
 from cutevariant.core import vql, sql
@@ -41,7 +41,7 @@ class VqlEditorWidget(plugin.PluginWidget):
 
     LOCATION = plugin.FOOTER_LOCATION
     ENABLE = True
-    REFRESH_STATE_DATA = {"fields", "filters", "source"}
+    REFRESH_STATE_DATA = {"fields", "filters", "source", "order_by"}
 
     def __init__(self, parent=None):
         super().__init__(parent)
@@ -50,9 +50,8 @@ class VqlEditorWidget(plugin.PluginWidget):
         # Top toolbar
         self.top_bar = QToolBar()
         self.top_bar.setToolButtonStyle(Qt.ToolButtonTextBesideIcon)
-        self.run_action = self.top_bar.addAction(
-            FIcon(0xF040A), self.tr("Run"), self.run_vql
-        )
+        self.run_action = self.top_bar.addAction(FIcon(0xF040A), self.tr("Run"), self.run_vql)
+        self.top_bar.setIconSize(QSize(16, 16))
         self.run_action.setShortcuts([Qt.CTRL + Qt.Key_R, QKeySequence.Refresh])
         self.run_action.setToolTip(
             self.tr("Run VQL query (%s)" % self.run_action.shortcut().toString())
@@ -64,9 +63,7 @@ class VqlEditorWidget(plugin.PluginWidget):
         self.log_edit = QLabel()
         self.log_edit.setMinimumHeight(40)
         self.log_edit.setStyleSheet(
-            "QWidget{{background-color:'{}'; color:'{}'}}".format(
-                style.WARNING_BACKGROUND_COLOR, style.WARNING_TEXT_COLOR
-            )
+            "QWidget{{background-color:'{}'; color:'{}'}}".format("orange", "black")
         )
         self.log_edit.hide()
         self.log_edit.setFrameStyle(QFrame.StyledPanel | QFrame.Raised)
@@ -90,6 +87,9 @@ class VqlEditorWidget(plugin.PluginWidget):
 
         self.on_refresh()
 
+    def on_close_project(self):
+        self.text_edit.clear()
+
     def on_refresh(self):
         """overrided from PluginWidget"""
 
@@ -97,6 +97,7 @@ class VqlEditorWidget(plugin.PluginWidget):
             self.mainwindow.get_state_data("fields"),
             self.mainwindow.get_state_data("source"),
             self.mainwindow.get_state_data("filters"),
+            self.mainwindow.get_state_data("order_by"),
         )
 
         self.set_vql(vql_query)
@@ -146,22 +147,28 @@ class VqlEditorWidget(plugin.PluginWidget):
             description = "<b>{}</b> ({}) from {} <br/><br/> {}".format(
                 field["name"], field["type"], field["category"], field["description"]
             )
-            color = style.FIELD_TYPE.get(field["type"], "str")["color"]
-            icon = FIcon(style.FIELD_TYPE.get(field["type"], "str")["icon"], "white")
+
+            # ===> TODO
+            # color = style.FIELD_TYPE.get(field["type"], "str")["color"]
+            # icon = FIcon(style.FIELD_TYPE.get(field["type"], "str")["icon"], "white")
+
+            color = "red"
+            icon = FIcon(0xF04EB)
 
             if field["category"] == "variants":
                 self.text_edit.completer.model.add_item(name, description, icon, color)
 
             if field["category"] == "annotations":
-                self.text_edit.completer.model.add_item(
-                    f"ann.{name}", description, icon, color
-                )
+                self.text_edit.completer.model.add_item(f"ann.{name}", description, icon, color)
 
             if field["category"] == "samples":
 
                 # Add AnySamples special keywords
                 # samples["*"].gt
-                name = "samples['*'].{}".format(field["name"])
+                name = "samples[ANY].{}".format(field["name"])
+                self.text_edit.completer.model.add_item(name, description, icon, color)
+
+                name = "samples[ALL].{}".format(field["name"])
                 self.text_edit.completer.model.add_item(name, description, icon, color)
 
                 # Overwrite name
@@ -174,9 +181,7 @@ class VqlEditorWidget(plugin.PluginWidget):
                         sample,
                         field["description"],
                     )
-                    self.text_edit.completer.model.add_item(
-                        name, description, icon, color
-                    )
+                    self.text_edit.completer.model.add_item(name, description, icon, color)
 
         self.text_edit.completer.model.endResetModel()
 
@@ -201,9 +206,7 @@ class VqlEditorWidget(plugin.PluginWidget):
         except (TextXSyntaxError, VQLSyntaxError) as e:
             # Show the error message on the ui
             # Available attributes: e.message, e.line, e.col
-            self.set_message(
-                "%s: %s, col: %d" % (e.__class__.__name__, e.message, e.col)
-            )
+            self.set_message("%s: %s, col: %d" % (e.__class__.__name__, e.message, e.col))
             return False
         return True
 
@@ -238,6 +241,10 @@ class VqlEditorWidget(plugin.PluginWidget):
                 # name of the variant selection
                 self.mainwindow.set_state_data("source", cmd["source"])
                 self.mainwindow.set_state_data("filters", cmd["filters"])
+
+                if "order_by" in cmd:
+                    self.mainwindow.set_state_data("order_by", cmd["order_by"])
+
                 # Refresh all plugins
                 self.mainwindow.refresh_plugins(sender=self)
                 continue
