@@ -5,7 +5,7 @@ import json
 import os
 
 # Qt imports
-from PySide2.QtCore import (
+from PySide6.QtCore import (
     Qt,
     QAbstractTableModel,
     QDateTime,
@@ -14,15 +14,15 @@ from PySide2.QtCore import (
     QUrl,
     QModelIndex,
     QSortFilterProxyModel,
+    QSize,
 )
-from PySide2.QtWidgets import (
+from PySide6.QtWidgets import (
     QToolBar,
     QVBoxLayout,
     QApplication,
     QFileDialog,
     QMessageBox,
     QTableView,
-    QAction,
     QHeaderView,
     QAbstractItemView,
     QSpacerItem,
@@ -30,7 +30,12 @@ from PySide2.QtWidgets import (
     QLineEdit,
 )
 
-from PySide2.QtGui import QDesktopServices, QKeySequence
+from PySide6.QtGui import (
+    QDesktopServices,
+    QKeySequence,
+    QAction,
+)
+
 
 # Custom imports
 from cutevariant.gui import style, plugin, FIcon, MainWindow
@@ -71,17 +76,20 @@ class HistoryModel(QAbstractTableModel):
         self.records = []
 
     def rowCount(self, parent: QModelIndex = QModelIndex()) -> int:
-        """ override :  Return Row Count"""
-        return len(self.records)
+        """override :  Return Row Count"""
+        if parent == QModelIndex():
+            return len(self.records)
+        else:
+            return 0
 
     def columnCount(self, parent: QModelIndex = QModelIndex()) -> int:
-        """ override : Return Column Count """
+        """override : Return Column Count"""
         if parent == QModelIndex():
             return 5
         return 0
 
     def data(self, index: QModelIndex, role: Qt.DisplayRole):
-        """ override: Return data according index and role """
+        """override: Return data according index and role"""
 
         if not index.isValid():
             return None
@@ -113,7 +121,7 @@ class HistoryModel(QAbstractTableModel):
         return None
 
     def setData(self, index, value, role=Qt.EditRole):
-        """ override : Set model data according index and role """
+        """override : Set model data according index and role"""
         if index.column() == 0:
             self.records[index.row()][0] = value
             return True
@@ -121,7 +129,7 @@ class HistoryModel(QAbstractTableModel):
             return False
 
     def headerData(self, section: int, orientation: Qt.Orientation, role):
-        """ override """
+        """override"""
 
         if orientation == Qt.Horizontal and role == Qt.DisplayRole:
             return HistoryModel.HEADERS[section]
@@ -156,7 +164,7 @@ class HistoryModel(QAbstractTableModel):
         self.endInsertRows()
 
     def from_json(self, records: dict):
-        """ Load from a json serialisable object"""
+        """Load from a json serialisable object"""
 
         self.beginResetModel()
         self.records.clear()
@@ -309,9 +317,7 @@ class HistoryDelegate(QStyledItemDelegate):
             syntax = VqlSyntaxHighlighter(doc)
             vql = index.data()
 
-            elided_vql = painter.fontMetrics().elidedText(
-                vql, Qt.ElideRight, area.width()
-            )
+            elided_vql = painter.fontMetrics().elidedText(vql, Qt.ElideRight, area.width())
             doc.setPlainText(elided_vql)
             # highlighter_->setDocument(&doc);
             # context.palette.setColor(QPalette.Text, painter.pen().color())
@@ -359,15 +365,9 @@ class VqlHistoryWidget(plugin.PluginWidget):
         # Hide name column (too ugly for now)
         self.view.hideColumn(0)
 
-        self.view.horizontalHeader().setSectionResizeMode(
-            0, QHeaderView.ResizeToContents
-        )
-        self.view.horizontalHeader().setSectionResizeMode(
-            1, QHeaderView.ResizeToContents
-        )
-        self.view.horizontalHeader().setSectionResizeMode(
-            2, QHeaderView.ResizeToContents
-        )
+        self.view.horizontalHeader().setSectionResizeMode(0, QHeaderView.ResizeToContents)
+        self.view.horizontalHeader().setSectionResizeMode(1, QHeaderView.ResizeToContents)
+        self.view.horizontalHeader().setSectionResizeMode(2, QHeaderView.ResizeToContents)
 
         self.view.horizontalHeader().setSectionResizeMode(3, QHeaderView.Stretch)
 
@@ -375,10 +375,8 @@ class VqlHistoryWidget(plugin.PluginWidget):
         #  Create toolbar
         self.toolbar = QToolBar()
         self.toolbar.setToolButtonStyle(Qt.ToolButtonTextBesideIcon)
-
-        self.toolbar.addAction(
-            FIcon(0xF0413), self.tr("Clear"), self.on_clear_logs_pressed
-        )
+        self.toolbar.setIconSize(QSize(16, 16))
+        self.toolbar.addAction(FIcon(0xF0413), self.tr("Clear"), self.on_clear_logs_pressed)
 
         self.toolbar.addAction(
             FIcon(0xF0DAE),
@@ -386,9 +384,7 @@ class VqlHistoryWidget(plugin.PluginWidget):
             self.on_import_history_pressed,
         )
 
-        self.toolbar.addAction(
-            FIcon(0xF0DAD), self.tr("Export..."), self.on_export_history_pressed
-        )
+        self.toolbar.addAction(FIcon(0xF0DAD), self.tr("Export..."), self.on_export_history_pressed)
 
         delete_row = self.toolbar.addAction(
             FIcon(0xF04F5),
@@ -410,7 +406,7 @@ class VqlHistoryWidget(plugin.PluginWidget):
 
         self.search_edit.setVisible(False)
         self.search_edit.setPlaceholderText(self.tr("Search query... "))
-        self.search_edit.textChanged.connect(self.proxy_model.setFilterRegExp)
+        self.search_edit.textChanged.connect(self.proxy_model.setFilterRegularExpression)
         self.search_edit.setContentsMargins(10, 10, 10, 10)
 
         # Create layout
@@ -425,7 +421,7 @@ class VqlHistoryWidget(plugin.PluginWidget):
         self.setLayout(main_layout)
 
     def on_register(self, mainwindow: MainWindow):
-        """ override  """
+        """override"""
         # mainwindow.variants_load_finished.connect(self.on_variants_load_finished)
         pass
 
@@ -441,6 +437,7 @@ class VqlHistoryWidget(plugin.PluginWidget):
             self.mainwindow.get_state_data("fields"),
             self.mainwindow.get_state_data("source"),
             self.mainwindow.get_state_data("filters"),
+            self.mainwindow.get_state_data("order_by"),
         )
 
         #  Do not store same query consecutively
@@ -449,7 +446,7 @@ class VqlHistoryWidget(plugin.PluginWidget):
             self.model.add_record(vql_query, count, elapsed_time)
 
     def on_open_project(self, conn):
-        """ override """
+        """override"""
         self.conn = conn
 
     def on_refresh(self):
@@ -461,11 +458,11 @@ class VqlHistoryWidget(plugin.PluginWidget):
             self.on_variants_load_finished(count, elapsed_time)
 
     def to_json(self):
-        """ override """
+        """override"""
         return self.model.to_json()
 
     def from_json(self, data):
-        """ override """
+        """override"""
         self.model.from_json(data)
 
     def on_double_clicked(self, index: QModelIndex):
@@ -476,11 +473,11 @@ class VqlHistoryWidget(plugin.PluginWidget):
         """
         query = self.model.get_query(index)
         parsed_query = next(vql.parse_vql(query))
-        print(parsed_query)
 
         self.mainwindow.set_state_data("fields", parsed_query["fields"])
         self.mainwindow.set_state_data("source", parsed_query["source"])
         self.mainwindow.set_state_data("filters", parsed_query["filters"])
+        self.mainwindow.set_state_data("order_by", parsed_query["order_by"])
 
         self.mainwindow.refresh_plugins(sender=self)
 
@@ -521,7 +518,7 @@ class VqlHistoryWidget(plugin.PluginWidget):
         self.search_edit.setFocus(Qt.MenuBarFocusReason)
 
     def on_clear_logs_pressed(self):
-        """Clear all records with a confirm message """
+        """Clear all records with a confirm message"""
         confirmation = QMessageBox.question(
             self,
             self.tr("Please confirm"),
@@ -562,9 +559,7 @@ class VqlHistoryWidget(plugin.PluginWidget):
             confirmation = QMessageBox.question(
                 self,
                 self.tr("Please confirm"),
-                self.tr(
-                    f"Do you really want to remove this row ?\nYou cannot undo this !"
-                ),
+                self.tr(f"Do you really want to remove this row ?\nYou cannot undo this !"),
             )
             if confirmation == QMessageBox.No:
                 return
