@@ -8,7 +8,7 @@ import typing
 
 # Qt imports
 
-from PySide2.QtWidgets import (
+from PySide6.QtWidgets import (
     QLineEdit,
     QTableView,
     QToolBar,
@@ -26,7 +26,7 @@ from PySide2.QtWidgets import (
     QMenu,
 )
 
-from PySide2.QtCore import (
+from PySide6.QtCore import (
     QAbstractTableModel,
     QMimeData,
     QModelIndex,
@@ -39,21 +39,21 @@ from PySide2.QtCore import (
     QUrl,
     Qt,
 )
-from PySide2.QtGui import QIcon, QContextMenuEvent, QKeyEvent, QKeySequence
+from PySide6.QtGui import QIcon, QContextMenuEvent, QKeyEvent, QKeySequence
 
 # Custom imports
 from cutevariant.gui.plugin import PluginWidget
 from cutevariant.core.sql import (
     get_sql_connection,
     get_wordsets,
-    get_words_in_set,
-    sanitize_words,
-    intersect_wordset,
-    union_wordset,
-    subtract_wordset,
+    get_wordset_by_name,
+    _sanitize_words,
+    insert_wordset_from_intersect,
+    insert_wordset_from_union,
+    insert_wordset_from_subtract,
 )
 from cutevariant.core.command import import_cmd, drop_cmd
-from cutevariant import commons as cm
+from cutevariant import constants as cst
 from cutevariant.gui.ficon import FIcon
 from cutevariant.gui.widgets import SearchableTableWidget
 
@@ -67,19 +67,30 @@ class WordListDialog(QDialog):
         super().__init__(parent)
 
         self.setWindowTitle(self.tr("Edit Word set"))
-        self.setWindowIcon(QIcon(cm.DIR_ICONS + "app.png"))
+        self.setWindowIcon(QIcon(cst.DIR_ICONS + "app.png"))
 
-        box = QVBoxLayout()
         self.add_button = QPushButton(FIcon(0xF0415), self.tr("Add"))
+        self.add_button.pressed.connect(self.on_add)
+
         self.paste_file_button = QPushButton(FIcon(0xF0192), self.tr("Paste"))
+        self.paste_file_button.pressed.connect(self.on_paste)
+
         self.add_file_button = QPushButton(FIcon(0xF0EED), self.tr("Add from file..."))
+        self.add_file_button.pressed.connect(self.on_load_file)
+
         self.del_button = QPushButton(FIcon(0xF0A7A), self.tr("Remove"))
         self.del_button.setDisabled(True)
+        self.del_button.pressed.connect(self.on_remove)
 
         self.save_button = QPushButton(self.tr("Save"))
         self.save_button.setDisabled(True)
-        self.cancel_button = QPushButton(self.tr("Cancel"))
+        self.save_button.pressed.connect(self.accept)
 
+        self.cancel_button = QPushButton(self.tr("Cancel"))
+        self.cancel_button.pressed.connect(self.reject)
+
+        # Item selected in view
+        box = QVBoxLayout()
         box.addWidget(self.add_button)
         box.addWidget(self.paste_file_button)
         box.addWidget(self.add_file_button)
@@ -88,36 +99,28 @@ class WordListDialog(QDialog):
         box.addWidget(self.save_button)
         box.addWidget(self.cancel_button)
 
-        self.view = QListView()
         self.model = QStringListModel()
-        self.view.setModel(self.model)
-        self.view.setSelectionMode(QAbstractItemView.ExtendedSelection)
-
-        vlayout = QVBoxLayout()
-        #  Create title label
-        self.title_label = QLabel()
-        self.title_label.setText(self.tr("Create a set by adding words"))
-        vlayout.addWidget(self.title_label)
-        vlayout.addWidget(self.view)
-
-        hlayout = QHBoxLayout()
-        hlayout.addLayout(vlayout)
-        hlayout.addLayout(box)
-
-        self.setLayout(hlayout)
-
-        self.add_button.pressed.connect(self.on_add)
-        self.del_button.pressed.connect(self.on_remove)
-        self.add_file_button.pressed.connect(self.on_load_file)
-        self.paste_file_button.pressed.connect(self.on_paste)
-        self.cancel_button.pressed.connect(self.reject)
-        self.save_button.pressed.connect(self.accept)
-        # Item selected in view
-        self.view.selectionModel().selectionChanged.connect(self.on_item_selected)
-        # Data changed in model
         self.model.dataChanged.connect(self.on_data_changed)
         self.model.rowsInserted.connect(self.on_data_changed)
         self.model.rowsRemoved.connect(self.on_data_changed)
+        self.model.modelReset.connect(self.on_data_changed)
+
+        self.view = QListView()
+        self.view.setModel(self.model)
+        self.view.setSelectionMode(QAbstractItemView.ExtendedSelection)
+        self.view.selectionModel().selectionChanged.connect(self.on_item_selected)
+
+        # Create title label
+        self.title_label = QLabel()
+        self.title_label.setText(self.tr("Create a set by adding words"))
+
+        vlayout = QVBoxLayout()
+        vlayout.addWidget(self.title_label)
+        vlayout.addWidget(self.view)
+
+        hlayout = QHBoxLayout(self)
+        hlayout.addLayout(vlayout)
+        hlayout.addLayout(box)
 
     def on_item_selected(self, *args):
         """Enable the remove button when an item is selected"""
@@ -125,7 +128,8 @@ class WordListDialog(QDialog):
 
     def on_data_changed(self, *args):
         """Enable the save button when data in model is changed"""
-        self.save_button.setEnabled(True)
+        enabled = len(self.model.stringList()) > 0
+        self.save_button.setEnabled(enabled)
 
     def on_paste(self):
         text = qApp.clipboard().text()
@@ -200,7 +204,7 @@ class WordListDialog(QDialog):
 
         # Sanitize words
         with open(filename, "r") as f_h:
-            data = sanitize_words(f_h)
+            data = _sanitize_words(f_h)
 
         data.update(self.model.stringList())
         self.model.setStringList(list(data))
@@ -216,11 +220,7 @@ class WordsetCollectionModel(QAbstractTableModel):
 
     def data(self, index: QModelIndex, role: int) -> typing.Any:
 
-        if (
-            index.row() < 0
-            or index.row() >= self.rowCount()
-            or index.column() not in (0, 1)
-        ):
+        if index.row() < 0 or index.row() >= self.rowCount() or index.column() not in (0, 1):
             return
 
         if role == Qt.DecorationRole and index.column() == 0:
@@ -232,14 +232,8 @@ class WordsetCollectionModel(QAbstractTableModel):
         if role == Qt.DisplayRole:
             return self._raw_data[index.row()][index.column()]
 
-    def headerData(
-        self, section: int, orientation: Qt.Orientation, role: int
-    ) -> typing.Any:
-        if (
-            orientation != Qt.Horizontal
-            or section not in (0, 1)
-            or role != Qt.DisplayRole
-        ):
+    def headerData(self, section: int, orientation: Qt.Orientation, role: int) -> typing.Any:
+        if orientation != Qt.Horizontal or section not in (0, 1) or role != Qt.DisplayRole:
             return
 
         if section == 0:
@@ -249,9 +243,7 @@ class WordsetCollectionModel(QAbstractTableModel):
 
     def load(self):
         if self.conn:
-            self._set_dict(
-                {data["name"]: data["count"] for data in get_wordsets(self.conn)}
-            )
+            self._set_dict({data["name"]: data["count"] for data in get_wordsets(self.conn)})
 
     def _set_dict(self, data: dict):
         self.beginResetModel()
@@ -271,9 +263,7 @@ class WordsetCollectionModel(QAbstractTableModel):
         return list(dict(self._raw_data).keys())
 
     def mimeData(self, indexes: typing.List) -> QMimeData:
-        wordset_names = [
-            idx.data(Qt.DisplayRole) for idx in indexes if idx.column() == 0
-        ]
+        wordset_names = [idx.data(Qt.DisplayRole) for idx in indexes if idx.column() == 0]
         if len(wordset_names) != 1:
             # Currently, we don't support dragging more than one wordset
             return None
@@ -373,7 +363,7 @@ class WordSetWidget(PluginWidget):
         super().__init__(parent)
         self.conn = None
         self.model = WordsetCollectionModel(parent=self)
-        self.setWindowIcon(FIcon(0xF10E3))
+        self.setWindowIcon(FIcon(0xF0C2E))
         self.toolbar = QToolBar(self)
         self.view = QTableView(self)
         self.view.setSortingEnabled(True)
@@ -390,9 +380,7 @@ class WordSetWidget(PluginWidget):
 
         # setup tool bar
         self.toolbar.setIconSize(QSize(16, 16))
-        self.toolbar.addAction(
-            FIcon(0xF0415), self.tr("Add Word set"), self.add_wordset
-        )
+        self.toolbar.addAction(FIcon(0xF0415), self.tr("Add Word set"), self.add_wordset)
         self.edit_action = self.toolbar.addAction(
             FIcon(0xF0DC9), self.tr("Edit Word set"), self.open_wordset
         )
@@ -508,8 +496,7 @@ class WordSetWidget(PluginWidget):
                 QMessageBox.critical(
                     self,
                     self.tr("Error while creating set"),
-                    self.tr("Error while creating set '%s'; Name is already used")
-                    % wordset_name,
+                    self.tr("Error while creating set '%s'; Name is already used") % wordset_name,
                 )
                 wordset_name = None
 
@@ -534,17 +521,14 @@ class WordSetWidget(PluginWidget):
 
         # Delete all selected sets
         for selected_index in self.view.selectionModel().selectedRows(0):
-            result = drop_cmd(
-                self.conn, "wordsets", selected_index.data(Qt.DisplayRole)
-            )
+            result = drop_cmd(self.conn, "wordsets", selected_index.data(Qt.DisplayRole))
 
             if not result["success"]:
                 LOGGER.error(result)
                 QMessageBox.critical(
                     self,
                     self.tr("Error while deleting set"),
-                    self.tr("Error while deleting set '%s'")
-                    % selected_index.data(Qt.DisplayRole),
+                    self.tr("Error while deleting set '%s'") % selected_index.data(Qt.DisplayRole),
                 )
 
         self.populate()
@@ -565,7 +549,7 @@ class WordSetWidget(PluginWidget):
         dialog = WordListDialog()
 
         # populate dialog
-        dialog.model.setStringList(list(get_words_in_set(self.conn, wordset_name)))
+        dialog.model.setStringList(list(get_wordset_by_name(self.conn, wordset_name)))
 
         if dialog.exec_() == QDialog.Accepted:
             drop_cmd(self.conn, "wordsets", wordset_name)
@@ -591,9 +575,7 @@ class WordSetWidget(PluginWidget):
         self.model.load()
         self.view.horizontalHeader().setStretchLastSection(False)
         self.view.horizontalHeader().setSectionResizeMode(0, QHeaderView.Stretch)
-        self.view.horizontalHeader().setSectionResizeMode(
-            1, QHeaderView.ResizeToContents
-        )
+        self.view.horizontalHeader().setSectionResizeMode(1, QHeaderView.ResizeToContents)
         self.update_action_availabilty()
 
     def on_apply_set_operation(self, operation="intersect"):
@@ -601,13 +583,12 @@ class WordSetWidget(PluginWidget):
         The resulting wordset will contain all elements from all selected wordsets, without double.
         """
         operations = {
-            "intersect": (intersect_wordset, self.tr("Intersect")),
-            "union": (union_wordset, self.tr("Union")),
-            "subtract": (subtract_wordset, self.tr("Subtract")),
+            "intersect": (insert_wordset_from_intersect, self.tr("Intersect")),
+            "union": (insert_wordset_from_union, self.tr("Union")),
+            "subtract": (insert_wordset_from_subtract, self.tr("Subtract")),
         }
         selected_wordsets = [
-            index.data(Qt.DisplayRole)
-            for index in self.view.selectionModel().selectedRows(0)
+            index.data(Qt.DisplayRole) for index in self.view.selectionModel().selectedRows(0)
         ]
         if not selected_wordsets:
             return
@@ -634,7 +615,7 @@ class WordSetWidget(PluginWidget):
                         % wordset_name,
                     )
                     wordset_name = None
-            operator_fn = operations.get(operation, intersect_wordset)[0]
+            operator_fn = operations.get(operation, insert_wordset_from_intersect)[0]
             operator_fn(self.conn, wordset_name, selected_wordsets)
             self.populate()
 
@@ -649,7 +630,7 @@ class WordSetWidget(PluginWidget):
 
 if __name__ == "__main__":
     import sys
-    from PySide2.QtWidgets import QApplication
+    from PySide6.QtWidgets import QApplication
 
     app = QApplication(sys.argv)
 
