@@ -1,4 +1,4 @@
-from PySide2.QtWidgets import (
+from PySide6.QtWidgets import (
     QWidget,
     QTextEdit,
     QApplication,
@@ -11,7 +11,7 @@ from PySide2.QtWidgets import (
     QFrame,
     QStyle,
 )
-from PySide2.QtGui import (
+from PySide6.QtGui import (
     QPainter,
     QTextCursor,
     QIcon,
@@ -22,8 +22,9 @@ from PySide2.QtGui import (
     QFontMetrics,
     QSyntaxHighlighter,
     QTextCharFormat,
+    QWheelEvent,
 )
-from PySide2.QtCore import (
+from PySide6.QtCore import (
     Qt,
     QSize,
     QStringListModel,
@@ -64,7 +65,10 @@ class VqlSyntaxHighlighter(QSyntaxHighlighter):
         "NULL",
         "COUNT",
         "IMPORT",
+        "ASC",
+        "DESC",
         "WORDSET",
+        "ORDER BY",
         "INTERSECT",
     )
 
@@ -81,10 +85,7 @@ class VqlSyntaxHighlighter(QSyntaxHighlighter):
                 # Keywords
                 # \b allows to perform a "whole words only"
                 "pattern": "|".join(
-                    (
-                        "\\b%s\\b" % keyword
-                        for keyword in VqlSyntaxHighlighter.sql_keywords
-                    )
+                    ("\\b%s\\b" % keyword for keyword in VqlSyntaxHighlighter.sql_keywords)
                 ),
                 "font": QFont.Bold,
                 "color": palette.color(QPalette.Highlight),  # default: Qt.darkBlue
@@ -92,20 +93,20 @@ class VqlSyntaxHighlighter(QSyntaxHighlighter):
             },
             {
                 # Strings simple quotes '...'
-                "pattern": r"\'.*\'",
-                "color": Qt.red,
+                "pattern": r"\'(\\.|[^\'])*\'",
+                "color": QColor(QApplication.style().colors().get("red", "red")),
                 "minimal": True,  # Need to stop match as soon as possible
             },
             {
                 # Strings double quotes: "..."
-                "pattern": r"\".*\"",
-                "color": Qt.red,
+                "pattern": r"\"(\\.|[^\"])*\"",
+                "color": QColor(QApplication.style().colors().get("red", "red")),
                 "minimal": True,  # Need to stop match as soon as possible
             },
             {
                 # Numbers
                 "pattern": r"\\b[-+]?[0-9]*\.?[0-9]+([eE][-+]?[0-9]+)?\\b",
-                "color": Qt.darkGreen,
+                "color": QColor(QApplication.style().colors().get("green", "green")),
             },
             {
                 # Comments
@@ -190,9 +191,7 @@ class CompleterModel(QAbstractListModel):
             icon (TYPE, optional): the icon
             color (None, optional): the background color icon
         """
-        self._items.append(
-            {"name": name, "description": description, "icon": icon, "color": color}
-        )
+        self._items.append({"name": name, "description": description, "icon": icon, "color": color})
 
     def rowCount(self, parent=QModelIndex()) -> int:
         """Override from QAbstractListModel
@@ -229,7 +228,7 @@ class CompleterModel(QAbstractListModel):
         if role == Qt.DecorationRole:
             return self._items[index.row()]["icon"]
 
-        if role == Qt.BackgroundColorRole:
+        if role == Qt.BackgroundRole:
             return QColor(self._items[index.row()]["color"])
 
         return None
@@ -239,9 +238,7 @@ class CompleterDelegate(QStyledItemDelegate):
 
     """CompleterDelegate is use by the completer to draw nicely icon and elements of the completer"""
 
-    def paint(
-        self, painter: QPainter, option: QStyleOptionViewItem, index: QModelIndex
-    ):
+    def paint(self, painter: QPainter, option: QStyleOptionViewItem, index: QModelIndex):
         """Paint a cell according index and option
 
         Args:
@@ -261,12 +258,10 @@ class CompleterDelegate(QStyledItemDelegate):
 
         # get icon and color background
         icon = index.data(Qt.DecorationRole)
-        icon_color = index.data(Qt.BackgroundColorRole)
+        icon_color = index.data(Qt.BackgroundRole)
 
         # draw icon background
-        area = QRect(
-            option.rect.x(), option.rect.y(), option.rect.height(), option.rect.height()
-        )
+        area = QRect(option.rect.x(), option.rect.y(), option.rect.height(), option.rect.height())
         painter.setPen(Qt.NoPen)
         painter.setBrush(QColor(icon_color))
         painter.drawRect(area)
@@ -409,14 +404,10 @@ class Completer(QWidget):
                 # use tab to move down/up in the list
                 if event.key() == Qt.Key_Tab:
                     if current.row() < self.proxy_model.rowCount() - 1:
-                        self.view.setCurrentIndex(
-                            self.proxy_model.index(current.row() + 1, 0)
-                        )
+                        self.view.setCurrentIndex(self.proxy_model.index(current.row() + 1, 0))
                 if event.key() == Qt.Key_Backtab:
                     if current.row() > 0:
-                        self.view.setCurrentIndex(
-                            self.proxy_model.index(current.row() - 1, 0)
-                        )
+                        self.view.setCurrentIndex(self.proxy_model.index(current.row() - 1, 0))
 
                 # Route other key event to the target ! This make possible to write text when completer is visible
                 self._target.event(event)
@@ -459,7 +450,7 @@ class Completer(QWidget):
 
         self.proxy_model.setFilterRegularExpression(
             QRegularExpression(
-                f"^{ self._completion_prefix}.*",
+                f".*{ self._completion_prefix}.*",
                 QRegularExpression.CaseInsensitiveOption,
             )
         )
@@ -528,7 +519,6 @@ class CodeEdit(QTextEdit):
 
         self.completer = Completer()
         self.completer.set_target(self)
-
         self.syntax = VqlSyntaxHighlighter(self.document())
         self.setAcceptRichText(False)
         font = QFont("monospace")
@@ -548,6 +538,17 @@ class CodeEdit(QTextEdit):
             Qt.Key_Down,
         ]
 
+    def wheelEvent(self, e: QWheelEvent) -> None:
+        fontPS = self.fontPointSize()
+        if (e.modifiers() == Qt.ControlModifier) and e.angleDelta().y() > 0:
+            self.setFontPointSize(fontPS + 2)
+        elif e.modifiers() == Qt.ControlModifier and e.angleDelta().y() < 0 and fontPS > 8:
+            self.setFontPointSize(fontPS - 2)
+
+        self.setPlainText(self.toPlainText())
+
+        super().wheelEvent(e)
+
     def keyPressEvent(self, event):
 
         if event.key() in self._ignore_keys and self.completer.isVisible():
@@ -597,14 +598,12 @@ class CodeEdit(QTextEdit):
         tc = self.textCursor()
         extra = len(self.completer.completion_prefix())
         text_under_cursor = self.text_under_cursor()
-        tc.movePosition(
-            QTextCursor.Left, QTextCursor.KeepAnchor, len(text_under_cursor)
-        )
+        tc.movePosition(QTextCursor.Left, QTextCursor.KeepAnchor, len(text_under_cursor))
 
         tc.removeSelectedText()
         # tc.movePosition(QTextCursor.Left)
         # tc.movePosition(QTextCursor.StartOfWord)
-        tc.insertText(completion + " ")
+        tc.insertText(completion)
 
 
 if __name__ == "__main__":
