@@ -1,7 +1,7 @@
 """Summary
 """
-from PySide2.QtCore import QUrl, QDir, Slot, QFile, QIODevice, QTime
-from PySide2.QtWidgets import (
+from PySide6.QtCore import QUrl, QDir, Slot, QFile, QIODevice, QTime
+from PySide6.QtWidgets import (
     QLabel,
     QProgressBar,
     QDialogButtonBox,
@@ -9,8 +9,8 @@ from PySide2.QtWidgets import (
     QApplication,
     QVBoxLayout,
 )
-from PySide2.QtGui import QFont
-from PySide2.QtNetwork import QNetworkAccessManager, QNetworkReply, QNetworkRequest
+from PySide6.QtGui import QFont
+from PySide6.QtNetwork import QNetworkAccessManager, QNetworkReply, QNetworkRequest
 import sys
 
 
@@ -126,9 +126,7 @@ class DownloadDialog(QDialog):
         h_read = self.human_readable_bytes(read)
         h_speed = self.human_readable_bytes(speed) + "/sec"
 
-        self.info_label.setText(
-            f"Time remaining {h_remaining} - {h_read} of {h_total} ({h_speed})"
-        )
+        self.info_label.setText(f"Time remaining {h_remaining} - {h_read} of {h_total} ({h_speed})")
 
         # Set progression
         self.progress.setRange(0, total)
@@ -164,9 +162,7 @@ if __name__ == "__main__":
     app = QApplication(sys.argv)
 
     dialog = DownloadDialog()
-    dialog.set_source(
-        QUrl("http://hgdownload.cse.ucsc.edu/goldenPath/hg19/bigZips/mrna.fa.gz")
-    )
+    dialog.set_source(QUrl("http://hgdownload.cse.ucsc.edu/goldenPath/hg19/bigZips/mrna.fa.gz"))
     dialog.set_destination(QDir("/tmp/"))
     dialog.start()
     dialog.show()
