@@ -1,6 +1,6 @@
 """Python adaptation of https://github.com/dridk/QJsonModel
 
-Supports Python 2 and 3 with PySide, PySide2, PyQt4 or PyQt5.
+Supports Python 2 and 3 with PySide, PySide6, PyQt4 or PyQt5.
 Requires https://github.com/mottosso/Qt.py
 
 Usage:
@@ -39,7 +39,7 @@ Changes:
 
 import json
 
-from PySide2 import QtWidgets, QtCore
+from PySide6 import QtWidgets, QtCore
 
 
 class QJsonTreeItem(object):
@@ -307,9 +307,7 @@ if __name__ == "__main__":
     model.load(document)
 
     # Sanity check
-    assert json.dumps(model.json(), sort_keys=True) == json.dumps(
-        document, sort_keys=True
-    )
+    assert json.dumps(model.json(), sort_keys=True) == json.dumps(document, sort_keys=True)
 
     view.show()
     view.resize(500, 300)
